@@ -37,7 +37,6 @@ from nipype.utils.misc import package_check
 
 package_check('numpy', '1.3', 'tutorial1')
 package_check('scipy', '0.7', 'tutorial1')
-package_check('networkx', '1.0', 'tutorial1')
 package_check('IPython', '0.10', 'tutorial1')
 
 
@@ -72,16 +71,16 @@ Map field names to individual subject runs
 """
 
 info = dict(dwi=[['subject_id', 'data']],
-            bvecs=[['subject_id','bvecs']],
-            bvals=[['subject_id','bvals']],
-            seed_file = [['subject_id','MASK_average_thal_right']],
-            target_masks = [['subject_id',['MASK_average_M1_right',
-                                           'MASK_average_S1_right',
-                                           'MASK_average_occipital_right',
-                                           'MASK_average_pfc_right',
-                                           'MASK_average_pmc_right',
-                                           'MASK_average_ppc_right',
-                                           'MASK_average_temporal_right']]])
+            bvecs=[['subject_id', 'bvecs']],
+            bvals=[['subject_id', 'bvals']],
+            seed_file=[['subject_id', 'MASK_average_thal_right']],
+            target_masks=[['subject_id', ['MASK_average_M1_right',
+                                          'MASK_average_S1_right',
+                                          'MASK_average_occipital_right',
+                                          'MASK_average_pfc_right',
+                                          'MASK_average_pmc_right',
+                                          'MASK_average_ppc_right',
+                                          'MASK_average_temporal_right']]])
 
 infosource = pe.Node(interface=util.IdentityInterface(fields=['subject_id']),
                      name="infosource")
@@ -107,8 +106,8 @@ functionality.
 """
 
 datasource = pe.Node(interface=nio.DataGrabber(infields=['subject_id'],
-                                               outfields=info.keys()),
-                     name = 'datasource')
+                                               outfields=list(info.keys())),
+                     name='datasource')
 
 datasource.inputs.template = "%s/%s"
 
@@ -135,42 +134,41 @@ computeTensor = pe.Workflow(name='computeTensor')
 extract the volume with b=0 (nodif_brain)
 """
 
-fslroi = pe.Node(interface=fsl.ExtractROI(),name='fslroi')
-fslroi.inputs.t_min=0
-fslroi.inputs.t_size=1
+fslroi = pe.Node(interface=fsl.ExtractROI(), name='fslroi')
+fslroi.inputs.t_min = 0
+fslroi.inputs.t_size = 1
 
 """
 create a brain mask from the nodif_brain
 """
 
-bet = pe.Node(interface=fsl.BET(),name='bet')
-bet.inputs.mask=True
-bet.inputs.frac=0.34
+bet = pe.Node(interface=fsl.BET(), name='bet')
+bet.inputs.mask = True
+bet.inputs.frac = 0.34
 
 """
 correct the diffusion weighted images for eddy_currents
 """
 
 eddycorrect = create_eddy_correct_pipeline('eddycorrect')
-eddycorrect.inputs.inputnode.ref_num=0
+eddycorrect.inputs.inputnode.ref_num = 0
 
 """
 compute the diffusion tensor in each voxel
 """
 
-dtifit = pe.Node(interface=fsl.DTIFit(),name='dtifit')
+dtifit = pe.Node(interface=fsl.DTIFit(), name='dtifit')
 
 """
 connect all the nodes for this workflow
 """
 
 computeTensor.connect([
-                        (fslroi,bet,[('roi_file','in_file')]),
-                        (eddycorrect, dtifit,[('outputnode.eddy_corrected','dwi')]),
-                        (infosource, dtifit,[['subject_id','base_name']]),
-                        (bet,dtifit,[('mask_file','mask')])
-                      ])
-
+    (fslroi, bet, [('roi_file', 'in_file')]),
+    (eddycorrect, dtifit, [('outputnode.eddy_corrected', 'dwi')]),
+    (infosource, dtifit, [['subject_id', 'base_name']]),
+    (bet, dtifit, [('mask_file', 'mask')])
+])
 
 
 """
@@ -189,7 +187,7 @@ estimate the diffusion parameters: phi, theta, and so on
 """
 
 bedpostx = create_bedpostx_pipeline()
-bedpostx.get_node("xfibres").iterables = ("n_fibres",[1,2])
+bedpostx.get_node("xfibres").iterables = ("n_fibres", [1, 2])
 
 
 flirt = pe.Node(interface=fsl.FLIRT(), name='flirt')
@@ -200,22 +198,22 @@ flirt.inputs.dof = 12
 perform probabilistic tracktography
 """
 
-probtrackx = pe.Node(interface=fsl.ProbTrackX(),name='probtrackx')
-probtrackx.inputs.mode='seedmask'
+probtrackx = pe.Node(interface=fsl.ProbTrackX(), name='probtrackx')
+probtrackx.inputs.mode = 'seedmask'
 probtrackx.inputs.c_thresh = 0.2
-probtrackx.inputs.n_steps=2000
-probtrackx.inputs.step_length=0.5
-probtrackx.inputs.n_samples=5000
-probtrackx.inputs.opd=True
-probtrackx.inputs.os2t=True
-probtrackx.inputs.loop_check=True
+probtrackx.inputs.n_steps = 2000
+probtrackx.inputs.step_length = 0.5
+probtrackx.inputs.n_samples = 5000
+probtrackx.inputs.opd = True
+probtrackx.inputs.os2t = True
+probtrackx.inputs.loop_check = True
 
 
 """
 perform hard segmentation on the output of probtrackx
 """
 
-findthebiggest = pe.Node(interface=fsl.FindTheBiggest(),name='findthebiggest')
+findthebiggest = pe.Node(interface=fsl.FindTheBiggest(), name='findthebiggest')
 
 
 """
@@ -223,25 +221,26 @@ connect all the nodes for this workflow
 """
 
 tractography.add_nodes([bedpostx, flirt])
-tractography.connect([(bedpostx,probtrackx,[('outputnode.thsamples','thsamples'),
-                                            ('outputnode.phsamples','phsamples'),
-                                            ('outputnode.fsamples','fsamples')
-                                            ]),
-                      (probtrackx,findthebiggest,[('targets','in_files')]),
-                      (flirt, probtrackx, [('out_matrix_file','xfm')])
-                     ])
+tractography.connect([(bedpostx, probtrackx, [('outputnode.thsamples', 'thsamples'),
+                                              ('outputnode.phsamples', 'phsamples'),
+                                              ('outputnode.fsamples', 'fsamples')
+                                              ]),
+                      (probtrackx, findthebiggest, [('targets', 'in_files')]),
+                      (flirt, probtrackx, [('out_matrix_file', 'xfm')])
+                      ])
 
 
 """
 Setup data storage area
 """
 
-datasink = pe.Node(interface=nio.DataSink(),name='datasink')
+datasink = pe.Node(interface=nio.DataSink(), name='datasink')
 datasink.inputs.base_directory = os.path.abspath('dtiresults')
 
+
 def getstripdir(subject_id):
     import os
-    return os.path.join(os.path.abspath('data/workingdir/dwiproc'),'_subject_id_%s' % subject_id)
+    return os.path.join(os.path.abspath('data/workingdir/dwiproc'), '_subject_id_%s' % subject_id)
 
 
 """
@@ -252,27 +251,25 @@ Setup the pipeline that combines the two workflows: tractography and computeTens
 dwiproc = pe.Workflow(name="dwiproc")
 dwiproc.base_dir = os.path.abspath('fsl_dti_tutorial')
 dwiproc.connect([
-                    (infosource,datasource,[('subject_id', 'subject_id')]),
-                    (datasource,computeTensor,[('dwi','fslroi.in_file'),
-                                               ('bvals','dtifit.bvals'),
-                                               ('bvecs','dtifit.bvecs'),
-                                               ('dwi','eddycorrect.inputnode.in_file')]),
-                    (datasource,tractography,[('bvals','bedpostx.inputnode.bvals'),
-                                              ('bvecs','bedpostx.inputnode.bvecs'),
-                                              ('seed_file','probtrackx.seed'),
-                                              ('target_masks','probtrackx.target_masks')
-                                              ]),
-                    (computeTensor,tractography,[('eddycorrect.outputnode.eddy_corrected','bedpostx.inputnode.dwi'),
-                                                 ('bet.mask_file','bedpostx.inputnode.mask'),
-                                                 ('bet.mask_file','probtrackx.mask'),
-                                                 ('fslroi.roi_file','flirt.reference')]),
-                    (infosource, datasink,[('subject_id','container'),
-                                           (('subject_id', getstripdir),'strip_dir')]),
-                    (tractography,datasink,[('findthebiggest.out_file','fbiggest.@biggestsegmentation')])
-                ])
+    (infosource, datasource, [('subject_id', 'subject_id')]),
+    (datasource, computeTensor, [('dwi', 'fslroi.in_file'),
+                                 ('bvals', 'dtifit.bvals'),
+                                 ('bvecs', 'dtifit.bvecs'),
+                                 ('dwi', 'eddycorrect.inputnode.in_file')]),
+    (datasource, tractography, [('bvals', 'bedpostx.inputnode.bvals'),
+                                ('bvecs', 'bedpostx.inputnode.bvecs'),
+                                ('seed_file', 'probtrackx.seed'),
+                                ('target_masks', 'probtrackx.target_masks')
+                                ]),
+    (computeTensor, tractography, [('eddycorrect.outputnode.eddy_corrected', 'bedpostx.inputnode.dwi'),
+                                   ('bet.mask_file', 'bedpostx.inputnode.mask'),
+                                   ('bet.mask_file', 'probtrackx.mask'),
+                                   ('fslroi.roi_file', 'flirt.reference')]),
+    (infosource, datasink, [('subject_id', 'container'),
+                            (('subject_id', getstripdir), 'strip_dir')]),
+    (tractography, datasink, [('findthebiggest.out_file', 'fbiggest.@biggestsegmentation')])
+])
 
 if __name__ == '__main__':
     dwiproc.run()
     dwiproc.write_graph()
-
-
