@@ -16,6 +16,10 @@ the nipype tutorial directory::
 
 """
 
+from __future__ import print_function
+from builtins import str
+from builtins import range
+
 from nipype.interfaces.nipy.model import FitGLM, EstimateContrast
 from nipype.interfaces.nipy.preprocess import ComputeMask
 
@@ -67,8 +71,8 @@ data_dir = os.path.abspath('data')
 # Specify the subject directories
 subject_list = ['s1']
 # Map field names to individual subject runs.
-info = dict(func=[['subject_id', ['f3','f5','f7','f10']]],
-            struct=[['subject_id','struct']])
+info = dict(func=[['subject_id', ['f3', 'f5', 'f7', 'f10']]],
+            struct=[['subject_id', 'struct']])
 
 infosource = pe.Node(interface=util.IdentityInterface(fields=['subject_id']),
                      name="infosource")
@@ -97,7 +101,7 @@ functionality.
 
 datasource = pe.Node(interface=nio.DataGrabber(infields=['subject_id'],
                                                outfields=['func', 'struct']),
-                     name = 'datasource')
+                     name='datasource')
 datasource.inputs.base_directory = data_dir
 datasource.inputs.template = '%s/%s.nii'
 datasource.inputs.template_args = info
@@ -118,12 +122,12 @@ intensity or movement.
 """
 
 art = pe.Node(interface=ra.ArtifactDetect(), name="art")
-art.inputs.use_differences      = [True, False]
-art.inputs.use_norm             = True
-art.inputs.norm_threshold       = 1
+art.inputs.use_differences = [True, False]
+art.inputs.use_norm = True
+art.inputs.norm_threshold = 1
 art.inputs.zintensity_threshold = 3
-art.inputs.mask_type            = 'file'
-art.inputs.parameter_source     = 'SPM'
+art.inputs.mask_type = 'file'
+art.inputs.parameter_source = 'SPM'
 
 
 """Use :class:`nipype.interfaces.spm.Coregister` to perform a rigid
@@ -138,7 +142,7 @@ coregister.inputs.jobtype = 'estimate'
 :class:`nipype.interfaces.spm.Smooth`.
 """
 
-smooth = pe.Node(interface=spm.Smooth(), name = "smooth")
+smooth = pe.Node(interface=spm.Smooth(), name="smooth")
 smooth.inputs.fwhm = 4
 
 """
@@ -156,11 +160,11 @@ paradigm was used for every participant.
 def subjectinfo(subject_id):
     from nipype.interfaces.base import Bunch
     from copy import deepcopy
-    print "Subject ID: %s\n"%str(subject_id)
+    print("Subject ID: %s\n" % str(subject_id))
     output = []
-    names = ['Task-Odd','Task-Even']
+    names = ['Task-Odd', 'Task-Even']
     for r in range(4):
-        onsets = [range(15,240,60),range(45,240,60)]
+        onsets = [list(range(15, 240, 60)), list(range(45, 240, 60))]
         output.insert(r,
                       Bunch(conditions=names,
                             onsets=deepcopy(onsets),
@@ -179,20 +183,20 @@ those conditions]. The condition names must match the `names` listed
 in the `subjectinfo` function described above.
 """
 
-cont1 = ('Task>Baseline','T', ['Task-Odd','Task-Even'],[0.5,0.5])
-cont2 = ('Task-Odd>Task-Even','T', ['Task-Odd','Task-Even'],[1,-1])
-contrasts = [cont1,cont2]
+cont1 = ('Task>Baseline', 'T', ['Task-Odd', 'Task-Even'], [0.5, 0.5])
+cont2 = ('Task-Odd>Task-Even', 'T', ['Task-Odd', 'Task-Even'], [1, -1])
+contrasts = [cont1, cont2]
 
 """Generate design information using
 :class:`nipype.interfaces.spm.SpecifyModel`. nipy accepts only design specified
 in seconds so "output_units" has always have to be set to "secs".
 """
 
-modelspec = pe.Node(interface=model.SpecifySPMModel(), name= "modelspec")
-modelspec.inputs.concatenate_runs        = True
-modelspec.inputs.input_units             = 'secs'
-modelspec.inputs.output_units            = 'secs'
-modelspec.inputs.time_repetition         = 3.
+modelspec = pe.Node(interface=model.SpecifySPMModel(), name="modelspec")
+modelspec.inputs.concatenate_runs = True
+modelspec.inputs.input_units = 'secs'
+modelspec.inputs.output_units = 'secs'
+modelspec.inputs.time_repetition = 3.
 modelspec.inputs.high_pass_filter_cutoff = 120
 
 """Fit the GLM model using nipy and ordinary least square method
@@ -208,9 +212,9 @@ for FSL and SPM
 """
 
 contrast_estimate = pe.Node(interface=EstimateContrast(), name="contrast_estimate")
-cont1 = ('Task>Baseline','T', ['Task-Odd','Task-Even'],[0.5,0.5])
-cont2 = ('Task-Odd>Task-Even','T', ['Task-Odd','Task-Even'],[1,-1])
-contrast_estimate.inputs.contrasts = [cont1,cont2]
+cont1 = ('Task>Baseline', 'T', ['Task-Odd', 'Task-Even'], [0.5, 0.5])
+cont2 = ('Task-Odd>Task-Even', 'T', ['Task-Odd', 'Task-Even'], [1, -1])
+contrast_estimate.inputs.contrasts = [cont1, cont2]
 
 """
 Setup the pipeline
@@ -239,30 +243,29 @@ l1pipeline = pe.Workflow(name="level1")
 l1pipeline.base_dir = os.path.abspath('nipy_tutorial/workingdir')
 
 l1pipeline.connect([(infosource, datasource, [('subject_id', 'subject_id')]),
-                  (datasource,realign,[('func','in_files')]),
-                  (realign, compute_mask, [('mean_image','mean_volume')]),
-                  (realign, coregister,[('mean_image', 'source'),
-                                        ('realigned_files','apply_to_files')]),
-                  (datasource, coregister,[('struct', 'target')]),
-                  (coregister, smooth, [('coregistered_files', 'in_files')]),
-                  (realign, modelspec,[('realignment_parameters','realignment_parameters')]),
-                  (smooth, modelspec,[('smoothed_files','functional_runs')]),
-                  (realign, art,[('realignment_parameters','realignment_parameters')]),
-                  (coregister, art,[('coregistered_files','realigned_files')]),
-                  (compute_mask,art,[('brain_mask','mask_file')]),
-                  (art, modelspec,[('outlier_files','outlier_files')]),
-                  (infosource, modelspec, [(("subject_id", subjectinfo), "subject_info")]),
-                  (modelspec, model_estimate,[('session_info','session_info')]),
-                  (compute_mask, model_estimate, [('brain_mask','mask')]),
-                  (model_estimate, contrast_estimate, [("beta","beta"),
-                                                        ("nvbeta","nvbeta"),
-                                                        ("s2","s2"),
-                                                        ("dof", "dof"),
-                                                        ("axis", "axis"),
-                                                        ("constants", "constants"),
-                                                        ("reg_names", "reg_names")])
-                  ])
+                    (datasource, realign, [('func', 'in_files')]),
+                    (realign, compute_mask, [('mean_image', 'mean_volume')]),
+                    (realign, coregister, [('mean_image', 'source'),
+                                           ('realigned_files', 'apply_to_files')]),
+                    (datasource, coregister, [('struct', 'target')]),
+                    (coregister, smooth, [('coregistered_files', 'in_files')]),
+                    (realign, modelspec, [('realignment_parameters', 'realignment_parameters')]),
+                    (smooth, modelspec, [('smoothed_files', 'functional_runs')]),
+                    (realign, art, [('realignment_parameters', 'realignment_parameters')]),
+                    (coregister, art, [('coregistered_files', 'realigned_files')]),
+                    (compute_mask, art, [('brain_mask', 'mask_file')]),
+                    (art, modelspec, [('outlier_files', 'outlier_files')]),
+                    (infosource, modelspec, [(("subject_id", subjectinfo), "subject_info")]),
+                    (modelspec, model_estimate, [('session_info', 'session_info')]),
+                    (compute_mask, model_estimate, [('brain_mask', 'mask')]),
+                    (model_estimate, contrast_estimate, [("beta", "beta"),
+                                                         ("nvbeta", "nvbeta"),
+                                                         ("s2", "s2"),
+                                                         ("dof", "dof"),
+                                                         ("axis", "axis"),
+                                                         ("constants", "constants"),
+                                                         ("reg_names", "reg_names")])
+                    ])
 
 if __name__ == '__main__':
     l1pipeline.run()
-
