@@ -43,6 +43,8 @@ specifically the 2mm versions of:
 - `MNI template <http://mindboggle.info/data/templates/ants/OASIS-30_Atropos_template_in_MNI152_2mm.nii.gz>`_
 """
 
+from __future__ import division, unicode_literals
+from builtins import open, range, str
 
 import os
 
@@ -65,7 +67,7 @@ mlab.MatlabCommand.set_default_matlab_cmd("matlab -nodisplay")
 # mlab.MatlabCommand.set_default_paths('/software/matlab/spm12')
 
 from nipype.algorithms.rapidart import ArtifactDetect
-from nipype.algorithms.misc import TSNR
+from nipype.algorithms.misc import TSNR, CalculateMedian
 from nipype.interfaces.utility import Rename, Merge, IdentityInterface
 from nipype.utils.filemanip import filename_to_list
 from nipype.interfaces.io import DataSink, FreeSurferSource
@@ -74,6 +76,7 @@ import numpy as np
 import scipy as sp
 import nibabel as nb
 
+
 imports = ['import os',
            'import nibabel as nb',
            'import numpy as np',
@@ -96,7 +99,7 @@ def get_info(dicom_files):
     meta = default_extractor(read_file(filename_to_list(dicom_files)[0],
                                        stop_before_pixels=True,
                                        force=True))
-    return (meta['RepetitionTime']/1000., meta['CsaImage.MosaicRefAcqTimes'],
+    return (meta['RepetitionTime'] / 1000., meta['CsaImage.MosaicRefAcqTimes'],
             meta['SpacingBetweenSlices'])
 
 
@@ -115,16 +118,17 @@ def median(in_files):
     """
     import numpy as np
     import nibabel as nb
+    from nipype.utils import NUMPY_MMAP
     average = None
     for idx, filename in enumerate(filename_to_list(in_files)):
-        img = nb.load(filename)
+        img = nb.load(filename, mmap=NUMPY_MMAP)
         data = np.median(img.get_data(), axis=3)
         if average is None:
             average = data
         else:
             average = average + data
-    median_img = nb.Nifti1Image(average/float(idx + 1),
-                                img.get_affine(), img.get_header())
+    median_img = nb.Nifti1Image(average / float(idx + 1), img.affine,
+                                img.header)
     filename = os.path.join(os.getcwd(), 'median.nii.gz')
     median_img.to_filename(filename)
     return filename
@@ -143,14 +147,15 @@ def bandpass_filter(files, lowpass_freq, highpass_freq, fs):
     from nipype.utils.filemanip import split_filename, list_to_filename
     import numpy as np
     import nibabel as nb
+    from nipype.utils import NUMPY_MMAP
     out_files = []
     for filename in filename_to_list(files):
         path, name, ext = split_filename(filename)
         out_file = os.path.join(os.getcwd(), name + '_bp' + ext)
-        img = nb.load(filename)
+        img = nb.load(filename, mmap=NUMPY_MMAP)
         timepoints = img.shape[-1]
         F = np.zeros((timepoints))
-        lowidx = timepoints/2 + 1
+        lowidx = int(timepoints / 2) + 1
         if lowpass_freq > 0:
             lowidx = np.round(lowpass_freq / fs * timepoints)
         highidx = 0
@@ -163,8 +168,7 @@ def bandpass_filter(files, lowpass_freq, highpass_freq, fs):
             filtered_data = data
         else:
             filtered_data = np.real(np.fft.ifftn(np.fft.fftn(data) * F))
-        img_out = nb.Nifti1Image(filtered_data, img.get_affine(),
-                                 img.get_header())
+        img_out = nb.Nifti1Image(filtered_data, img.affine, img.header)
         img_out.to_filename(out_file)
         out_files.append(out_file)
     return list_to_filename(out_files)
@@ -188,7 +192,7 @@ def motion_regressors(motion_params, order=0, derivatives=1):
         for i in range(2, order + 1):
             out_params2 = np.hstack((out_params2, np.power(out_params, i)))
         filename = os.path.join(os.getcwd(), "motion_regressor%02d.txt" % idx)
-        np.savetxt(filename, out_params2, fmt="%.10f")
+        np.savetxt(filename, out_params2, fmt=b"%.10f")
         out_files.append(filename)
     return out_files
 
@@ -236,7 +240,7 @@ def build_filter1(motion_params, comp_norm, outliers, detrend_poly=None):
                     i + 1)(np.linspace(-1, 1, timepoints))[:, None]))
             out_params = np.hstack((out_params, X))
         filename = os.path.join(os.getcwd(), "filter_regressor%02d.txt" % idx)
-        np.savetxt(filename, out_params, fmt="%.10f")
+        np.savetxt(filename, out_params, fmt=b"%.10f")
         out_files.append(filename)
     return out_files
 
@@ -259,11 +263,12 @@ def extract_noise_components(realigned_file, mask_file, num_components=5,
     from scipy.linalg.decomp_svd import svd
     import numpy as np
     import nibabel as nb
+    from nipype.utils import NUMPY_MMAP
     import os
-    imgseries = nb.load(realigned_file)
+    imgseries = nb.load(realigned_file, mmap=NUMPY_MMAP)
     components = None
     for filename in filename_to_list(mask_file):
-        mask = nb.load(filename).get_data()
+        mask = nb.load(filename, mmap=NUMPY_MMAP).get_data()
         if len(np.nonzero(mask > 0)[0]) == 0:
             continue
         voxel_timecourses = imgseries.get_data()[mask > 0]
@@ -275,7 +280,7 @@ def extract_noise_components(realigned_file, mask_file, num_components=5,
         stdX[stdX == 0] = 1.
         stdX[np.isnan(stdX)] = 1.
         stdX[np.isinf(stdX)] = 1.
-        X = (X - np.mean(X, axis=0))/stdX
+        X = (X - np.mean(X, axis=0)) / stdX
         u, _, _ = svd(X, full_matrices=False)
         if components is None:
             components = u[:, :num_components]
@@ -285,7 +290,7 @@ def extract_noise_components(realigned_file, mask_file, num_components=5,
         regressors = np.genfromtxt(extra_regressors)
         components = np.hstack((components, regressors))
     components_file = os.path.join(os.getcwd(), 'noise_components.txt')
-    np.savetxt(components_file, components, fmt="%.10f")
+    np.savetxt(components_file, components, fmt=b"%.10f")
     return components_file
 
 
@@ -328,10 +333,11 @@ def extract_subrois(timeseries_file, label_file, indices):
     """
     from nipype.utils.filemanip import split_filename
     import nibabel as nb
+    from nipype.utils import NUMPY_MMAP
     import os
-    img = nb.load(timeseries_file)
+    img = nb.load(timeseries_file, mmap=NUMPY_MMAP)
     data = img.get_data()
-    roiimg = nb.load(label_file)
+    roiimg = nb.load(label_file, mmap=NUMPY_MMAP)
     rois = roiimg.get_data()
     prefix = split_filename(timeseries_file)[1]
     out_ts_file = os.path.join(os.getcwd(), '%s_subcortical_ts.txt' % prefix)
@@ -351,8 +357,9 @@ def combine_hemi(left, right):
     """
     import os
     import numpy as np
-    lh_data = nb.load(left).get_data()
-    rh_data = nb.load(right).get_data()
+    from nipype.utils import NUMPY_MMAP
+    lh_data = nb.load(left, mmap=NUMPY_MMAP).get_data()
+    rh_data = nb.load(right, mmap=NUMPY_MMAP).get_data()
 
     indices = np.vstack((1000000 + np.arange(0, lh_data.shape[0])[:, None],
                          2000000 + np.arange(0, rh_data.shape[0])[:, None]))
@@ -420,7 +427,7 @@ def create_reg_workflow(name='registration'):
 
     # Coregister the median to the surface
     bbregister = Node(freesurfer.BBRegister(),
-                    name='bbregister')
+                      name='bbregister')
     bbregister.inputs.init = 'fsl'
     bbregister.inputs.contrast_type = 't2'
     bbregister.inputs.out_fsl_file = True
@@ -482,7 +489,7 @@ def create_reg_workflow(name='registration'):
     convert2itk.inputs.fsl2ras = True
     convert2itk.inputs.itk_transform = True
     register.connect(bbregister, 'out_fsl_file', convert2itk, 'transform_file')
-    register.connect(inputnode, 'mean_image',convert2itk, 'source_file')
+    register.connect(inputnode, 'mean_image', convert2itk, 'source_file')
     register.connect(stripper, 'out_file', convert2itk, 'reference_file')
 
     """
@@ -512,7 +519,7 @@ def create_reg_workflow(name='registration'):
     reg.inputs.convergence_window_size = [20] * 2 + [5]
     reg.inputs.smoothing_sigmas = [[4, 2, 1]] * 2 + [[1, 0.5, 0]]
     reg.inputs.sigma_units = ['vox'] * 3
-    reg.inputs.shrink_factors = [[3, 2, 1]]*2 + [[4, 2, 1]]
+    reg.inputs.shrink_factors = [[3, 2, 1]] * 2 + [[4, 2, 1]]
     reg.inputs.use_estimate_learning_rate_once = [True] * 3
     reg.inputs.use_histogram_matching = [False] * 2 + [True]
     reg.inputs.winsorize_lower_quantile = 0.005
@@ -522,7 +529,7 @@ def create_reg_workflow(name='registration'):
     reg.inputs.num_threads = 4
     reg.plugin_args = {'qsub_args': '-l nodes=1:ppn=4'}
     register.connect(stripper, 'out_file', reg, 'moving_image')
-    register.connect(inputnode,'target_image', reg,'fixed_image')
+    register.connect(inputnode, 'target_image', reg, 'fixed_image')
 
     """
     Concatenate the affine and ants transforms into a list
@@ -540,11 +547,11 @@ def create_reg_workflow(name='registration'):
     warpmean.inputs.input_image_type = 3
     warpmean.inputs.interpolation = 'Linear'
     warpmean.inputs.invert_transform_flags = [False, False]
-    warpmean.inputs.terminal_output = 'file'
+    warpmean.terminal_output = 'file'
     warpmean.inputs.args = '--float'
     warpmean.inputs.num_threads = 4
 
-    register.connect(inputnode,'target_image', warpmean,'reference_image')
+    register.connect(inputnode, 'target_image', warpmean, 'reference_image')
     register.connect(inputnode, 'mean_image', warpmean, 'input_image')
     register.connect(merge, 'out', warpmean, 'transforms')
 
@@ -597,7 +604,7 @@ def create_workflow(files,
                           iterfield=['in_file', 'run'],
                           name='rename')
     name_unique.inputs.keep_ext = True
-    name_unique.inputs.run = range(1, len(files) + 1)
+    name_unique.inputs.run = list(range(1, len(files) + 1))
     name_unique.inputs.in_file = files
 
     realign = Node(interface=spm.Realign(), name="realign")
@@ -607,20 +614,16 @@ def create_workflow(files,
     slice_timing = Node(interface=spm.SliceTiming(), name="slice_timing")
     slice_timing.inputs.num_slices = num_slices
     slice_timing.inputs.time_repetition = TR
-    slice_timing.inputs.time_acquisition = TR - TR/float(num_slices)
+    slice_timing.inputs.time_acquisition = TR - TR / float(num_slices)
     slice_timing.inputs.slice_order = (np.argsort(slice_times) + 1).tolist()
-    slice_timing.inputs.ref_slice = int(num_slices/2)
+    slice_timing.inputs.ref_slice = int(num_slices / 2)
 
     # Comute TSNR on realigned data regressing polynomials upto order 2
     tsnr = MapNode(TSNR(regress_poly=2), iterfield=['in_file'], name='tsnr')
     wf.connect(slice_timing, 'timecorrected_files', tsnr, 'in_file')
 
     # Compute the median image across runs
-    calc_median = Node(Function(input_names=['in_files'],
-                                output_names=['median_file'],
-                                function=median,
-                                imports=imports),
-                       name='median')
+    calc_median = Node(CalculateMedian(), name='median')
     wf.connect(tsnr, 'detrended_file', calc_median, 'in_files')
 
     """Segment and Register
@@ -632,7 +635,6 @@ def create_workflow(files,
     registration.inputs.inputspec.subjects_dir = subjects_dir
     registration.inputs.inputspec.target_image = target_file
 
-
     """Use :class:`nipype.algorithms.rapidart` to determine which of the
     images in the functional series are outliers based on deviations in
     intensity or movement.
@@ -646,7 +648,6 @@ def create_workflow(files,
     art.inputs.mask_type = 'spm_global'
     art.inputs.parameter_source = 'SPM'
 
-
     """Here we are connecting all the nodes together. Notice that we add the merge node only if you choose
     to use 4D. Also `get_vox_dims` function is passed along the input volume of normalise to set the optimal
     voxel sizes.
@@ -696,7 +697,6 @@ def create_workflow(files,
     wf.connect(art, 'norm_files', createfilter1, 'comp_norm')
     wf.connect(art, 'outlier_files', createfilter1, 'outliers')
 
-
     filter1 = MapNode(fsl.GLM(out_f_name='F_mcart.nii',
                               out_pf_name='pF_mcart.nii',
                               demean=True),
@@ -708,7 +708,6 @@ def create_workflow(files,
                filter1, 'out_res_name')
     wf.connect(createfilter1, 'out_files', filter1, 'design')
 
-
     createfilter2 = MapNode(Function(input_names=['realigned_file', 'mask_file',
                                                   'num_components',
                                                   'extra_regressors'],
@@ -724,7 +723,6 @@ def create_workflow(files,
     wf.connect(registration, ('outputspec.segmentation_files', selectindex, [0, 2]),
                createfilter2, 'mask_file')
 
-
     filter2 = MapNode(fsl.GLM(out_f_name='F.nii',
                               out_pf_name='pF.nii',
                               demean=True),
@@ -737,12 +735,12 @@ def create_workflow(files,
     wf.connect(mask, 'mask_file', filter2, 'mask')
 
     bandpass = Node(Function(input_names=['files', 'lowpass_freq',
-                                           'highpass_freq', 'fs'],
-                              output_names=['out_files'],
-                              function=bandpass_filter,
-                              imports=imports),
-                     name='bandpass_unsmooth')
-    bandpass.inputs.fs = 1./TR
+                                          'highpass_freq', 'fs'],
+                             output_names=['out_files'],
+                             function=bandpass_filter,
+                             imports=imports),
+                    name='bandpass_unsmooth')
+    bandpass.inputs.fs = 1. / TR
     bandpass.inputs.highpass_freq = highpass_freq
     bandpass.inputs.lowpass_freq = lowpass_freq
     wf.connect(filter2, 'out_res', bandpass, 'files')
@@ -769,7 +767,7 @@ def create_workflow(files,
     warpall.inputs.input_image_type = 3
     warpall.inputs.interpolation = 'Linear'
     warpall.inputs.invert_transform_flags = [False, False]
-    warpall.inputs.terminal_output = 'file'
+    warpall.terminal_output = 'file'
     warpall.inputs.reference_image = target_file
     warpall.inputs.args = '--float'
     warpall.inputs.num_threads = 1
@@ -800,9 +798,9 @@ def create_workflow(files,
                           iterfield=['in_file', 'summary_file',
                                      'avgwf_txt_file'],
                           name='aparc_ts')
-    sampleaparc.inputs.segment_id = ([8] + range(10, 14) + [17, 18, 26, 47] +
-                                     range(49, 55) + [58] + range(1001, 1036) +
-                                     range(2001, 2036))
+    sampleaparc.inputs.segment_id = ([8] + list(range(10, 14)) + [17, 18, 26, 47] +
+                                     list(range(49, 55)) + [58] + list(range(1001, 1036)) +
+                                     list(range(2001, 2036)))
 
     wf.connect(registration, 'outputspec.aparc',
                sampleaparc, 'segmentation_file')
@@ -837,7 +835,7 @@ def create_workflow(files,
     samplerlh.inputs.sampling_units = "frac"
     samplerlh.inputs.interp_method = "trilinear"
     samplerlh.inputs.smooth_surf = surf_fwhm
-    #samplerlh.inputs.cortex_mask = True
+    # samplerlh.inputs.cortex_mask = True
     samplerlh.inputs.out_type = 'niigz'
     samplerlh.inputs.subjects_dir = subjects_dir
 
@@ -871,8 +869,8 @@ def create_workflow(files,
                               imports=imports),
                      iterfield=['timeseries_file'],
                      name='getsubcortts')
-    ts2txt.inputs.indices = [8] + range(10, 14) + [17, 18, 26, 47] +\
-                            range(49, 55) + [58]
+    ts2txt.inputs.indices = [8] + list(range(10, 14)) + [17, 18, 26, 47] +\
+        list(range(49, 55)) + [58]
     ts2txt.inputs.label_file = \
         os.path.abspath(('OASIS-TRT-20_jointfusion_DKT31_CMA_labels_in_MNI152_'
                          '2mm_v2.nii.gz'))
@@ -901,7 +899,7 @@ def create_workflow(files,
     datasink.inputs.base_directory = sink_directory
     datasink.inputs.container = subject_id
     datasink.inputs.substitutions = substitutions
-    datasink.inputs.regexp_substitutions = regex_subs #(r'(/_.*(\d+/))', r'/run\2')
+    datasink.inputs.regexp_substitutions = regex_subs  # (r'(/_.*(\d+/))', r'/run\2')
     wf.connect(realign, 'realignment_parameters', datasink, 'resting.qa.motion')
     wf.connect(art, 'norm_files', datasink, 'resting.qa.art.@norm')
     wf.connect(art, 'intensity_files', datasink, 'resting.qa.art.@intensity')
@@ -932,7 +930,7 @@ def create_workflow(files,
     datasink2.inputs.base_directory = sink_directory
     datasink2.inputs.container = subject_id
     datasink2.inputs.substitutions = substitutions
-    datasink2.inputs.regexp_substitutions = regex_subs #(r'(/_.*(\d+/))', r'/run\2')
+    datasink2.inputs.regexp_substitutions = regex_subs  # (r'(/_.*(\d+/))', r'/run\2')
     wf.connect(combiner, 'out_file',
                datasink2, 'resting.parcellations.grayo.@surface')
     return wf
@@ -948,7 +946,7 @@ def create_resting_workflow(args, name=None):
     slice_times = args.slice_times
     if args.dicom_file:
         TR, slice_times, slice_thickness = get_info(args.dicom_file)
-        slice_times = (np.array(slice_times)/1000.).tolist()
+        slice_times = (np.array(slice_times) / 1000.).tolist()
     if name is None:
         name = 'resting_' + args.subject_id
     kwargs = dict(files=[os.path.abspath(filename) for filename in args.files],
