@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 """
-====================================
+=====================================
 rsfMRI: ANTS, FS, FSL, NiPy, aCompCor
-====================================
+=====================================
 
 
 A preprocessing workflow for Siemens resting state data.
@@ -44,15 +44,20 @@ specifically the 2mm versions of:
 
 """
 
+from __future__ import division, unicode_literals
+from builtins import open, range, str
+
 import os
 
 from nipype.interfaces.base import CommandLine
 CommandLine.set_default_terminal_output('allatonce')
 
+# https://github.com/moloney/dcmstack
 from dcmstack.extract import default_extractor
+# pip install pydicom
 from dicom import read_file
 
-from nipype.interfaces import (fsl, Function, ants, freesurfer,nipy)
+from nipype.interfaces import (fsl, Function, ants, freesurfer, nipy)
 from nipype.interfaces.c3 import C3dAffineTool
 
 fsl.FSLCommand.set_default_output_type('NIFTI_GZ')
@@ -60,7 +65,8 @@ fsl.FSLCommand.set_default_output_type('NIFTI_GZ')
 from nipype import Workflow, Node, MapNode
 
 from nipype.algorithms.rapidart import ArtifactDetect
-from nipype.algorithms.misc import TSNR
+from nipype.algorithms.misc import TSNR, CalculateMedian
+from nipype.algorithms.confounds import ACompCor
 from nipype.interfaces.utility import Rename, Merge, IdentityInterface
 from nipype.utils.filemanip import filename_to_list
 from nipype.interfaces.io import DataSink, FreeSurferSource
@@ -69,6 +75,7 @@ import nipype.interfaces.freesurfer as fs
 import numpy as np
 import scipy as sp
 import nibabel as nb
+from nipype.utils.config import NUMPY_MMAP
 
 imports = ['import os',
            'import nibabel as nb',
@@ -91,7 +98,7 @@ def get_info(dicom_files):
     meta = default_extractor(read_file(filename_to_list(dicom_files)[0],
                                        stop_before_pixels=True,
                                        force=True))
-    return (meta['RepetitionTime']/1000., meta['CsaImage.MosaicRefAcqTimes'],
+    return (meta['RepetitionTime'] / 1000., meta['CsaImage.MosaicRefAcqTimes'],
             meta['SpacingBetweenSlices'])
 
 
@@ -110,14 +117,14 @@ def median(in_files):
     """
     average = None
     for idx, filename in enumerate(filename_to_list(in_files)):
-        img = nb.load(filename)
+        img = nb.load(filename, mmap=NUMPY_MMAP)
         data = np.median(img.get_data(), axis=3)
         if average is None:
             average = data
         else:
             average = average + data
-    median_img = nb.Nifti1Image(average/float(idx + 1),
-                                img.get_affine(), img.get_header())
+    median_img = nb.Nifti1Image(average / float(idx + 1), img.affine,
+                                img.header)
     filename = os.path.join(os.getcwd(), 'median.nii.gz')
     median_img.to_filename(filename)
     return filename
@@ -137,10 +144,10 @@ def bandpass_filter(files, lowpass_freq, highpass_freq, fs):
     for filename in filename_to_list(files):
         path, name, ext = split_filename(filename)
         out_file = os.path.join(os.getcwd(), name + '_bp' + ext)
-        img = nb.load(filename)
+        img = nb.load(filename, mmap=NUMPY_MMAP)
         timepoints = img.shape[-1]
         F = np.zeros((timepoints))
-        lowidx = timepoints/2 + 1
+        lowidx = int(timepoints / 2) + 1
         if lowpass_freq > 0:
             lowidx = np.round(float(lowpass_freq) / fs * timepoints)
         highidx = 0
@@ -153,8 +160,7 @@ def bandpass_filter(files, lowpass_freq, highpass_freq, fs):
             filtered_data = data
         else:
             filtered_data = np.real(np.fft.ifftn(np.fft.fftn(data) * F))
-        img_out = nb.Nifti1Image(filtered_data, img.get_affine(),
-                                 img.get_header())
+        img_out = nb.Nifti1Image(filtered_data, img.affine, img.header)
         img_out.to_filename(out_file)
         out_files.append(out_file)
     return list_to_filename(out_files)
@@ -177,7 +183,7 @@ def motion_regressors(motion_params, order=0, derivatives=1):
         for i in range(2, order + 1):
             out_params2 = np.hstack((out_params2, np.power(out_params, i)))
         filename = os.path.join(os.getcwd(), "motion_regressor%02d.txt" % idx)
-        np.savetxt(filename, out_params2, fmt="%.10f")
+        np.savetxt(filename, out_params2, fmt=b"%.10f")
         out_files.append(filename)
     return out_files
 
@@ -222,55 +228,10 @@ def build_filter1(motion_params, comp_norm, outliers, detrend_poly=None):
                     i + 1)(np.linspace(-1, 1, timepoints))[:, None]))
             out_params = np.hstack((out_params, X))
         filename = os.path.join(os.getcwd(), "filter_regressor%02d.txt" % idx)
-        np.savetxt(filename, out_params, fmt="%.10f")
+        np.savetxt(filename, out_params, fmt=b"%.10f")
         out_files.append(filename)
     return out_files
 
-
-def extract_noise_components(realigned_file, mask_file, num_components=5,
-                             extra_regressors=None):
-    """Derive components most reflective of physiological noise
-
-    Parameters
-    ----------
-    realigned_file: a 4D Nifti file containing realigned volumes
-    mask_file: a 3D Nifti file containing white matter + ventricular masks
-    num_components: number of components to use for noise decomposition
-    extra_regressors: additional regressors to add
-
-    Returns
-    -------
-    components_file: a text file containing the noise components
-    """
-    imgseries = nb.load(realigned_file)
-    components = None
-    for filename in filename_to_list(mask_file):
-        mask = nb.load(filename).get_data()
-        if len(np.nonzero(mask > 0)[0]) == 0:
-            continue
-        voxel_timecourses = imgseries.get_data()[mask > 0]
-        voxel_timecourses[np.isnan(np.sum(voxel_timecourses, axis=1)), :] = 0
-        # remove mean and normalize by variance
-        # voxel_timecourses.shape == [nvoxels, time]
-        X = voxel_timecourses.T
-        stdX = np.std(X, axis=0)
-        stdX[stdX == 0] = 1.
-        stdX[np.isnan(stdX)] = 1.
-        stdX[np.isinf(stdX)] = 1.
-        X = (X - np.mean(X, axis=0))/stdX
-        u, _, _ = sp.linalg.svd(X, full_matrices=False)
-        if components is None:
-            components = u[:, :num_components]
-        else:
-            components = np.hstack((components, u[:, :num_components]))
-    if extra_regressors:
-        regressors = np.genfromtxt(extra_regressors)
-        components = np.hstack((components, regressors))
-    components_file = os.path.join(os.getcwd(), 'noise_components.txt')
-    np.savetxt(components_file, components, fmt="%.10f")
-    return components_file
-
-
 def rename(in_files, suffix=None):
     from nipype.utils.filemanip import (filename_to_list, split_filename,
                                         list_to_filename)
@@ -308,9 +269,9 @@ def extract_subrois(timeseries_file, label_file, indices):
         The first four columns are: freesurfer index, i, j, k positions in the
         label file
     """
-    img = nb.load(timeseries_file)
+    img = nb.load(timeseries_file, mmap=NUMPY_MMAP)
     data = img.get_data()
-    roiimg = nb.load(label_file)
+    roiimg = nb.load(label_file, mmap=NUMPY_MMAP)
     rois = roiimg.get_data()
     prefix = split_filename(timeseries_file)[1]
     out_ts_file = os.path.join(os.getcwd(), '%s_subcortical_ts.txt' % prefix)
@@ -328,8 +289,8 @@ def extract_subrois(timeseries_file, label_file, indices):
 def combine_hemi(left, right):
     """Combine left and right hemisphere time series into a single text file
     """
-    lh_data = nb.load(left).get_data()
-    rh_data = nb.load(right).get_data()
+    lh_data = nb.load(left, mmap=NUMPY_MMAP).get_data()
+    rh_data = nb.load(right, mmap=NUMPY_MMAP).get_data()
 
     indices = np.vstack((1000000 + np.arange(0, lh_data.shape[0])[:, None],
                          2000000 + np.arange(0, rh_data.shape[0])[:, None]))
@@ -398,7 +359,7 @@ def create_reg_workflow(name='registration'):
 
     # Coregister the median to the surface
     bbregister = Node(freesurfer.BBRegister(),
-                    name='bbregister')
+                      name='bbregister')
     bbregister.inputs.init = 'fsl'
     bbregister.inputs.contrast_type = 't2'
     bbregister.inputs.out_fsl_file = True
@@ -413,7 +374,7 @@ def create_reg_workflow(name='registration'):
 
     binarize = Node(fs.Binarize(min=0.5, out_type="nii.gz", dilate=1), name="binarize_aparc")
     register.connect(fssource, ("aparc_aseg", get_aparc_aseg), binarize, "in_file")
-    stripper = Node(fsl.ApplyMask(), name ='stripper')
+    stripper = Node(fsl.ApplyMask(), name='stripper')
     register.connect(binarize, "binary_file", stripper, "mask_file")
     register.connect(convert, 'out_file', stripper, 'in_file')
 
@@ -463,7 +424,7 @@ def create_reg_workflow(name='registration'):
     convert2itk.inputs.fsl2ras = True
     convert2itk.inputs.itk_transform = True
     register.connect(bbregister, 'out_fsl_file', convert2itk, 'transform_file')
-    register.connect(inputnode, 'mean_image',convert2itk, 'source_file')
+    register.connect(inputnode, 'mean_image', convert2itk, 'source_file')
     register.connect(stripper, 'out_file', convert2itk, 'reference_file')
 
     """
@@ -493,7 +454,7 @@ def create_reg_workflow(name='registration'):
     reg.inputs.convergence_window_size = [20] * 2 + [5]
     reg.inputs.smoothing_sigmas = [[4, 2, 1]] * 2 + [[1, 0.5, 0]]
     reg.inputs.sigma_units = ['vox'] * 3
-    reg.inputs.shrink_factors = [[3, 2, 1]]*2 + [[4, 2, 1]]
+    reg.inputs.shrink_factors = [[3, 2, 1]] * 2 + [[4, 2, 1]]
     reg.inputs.use_estimate_learning_rate_once = [True] * 3
     reg.inputs.use_histogram_matching = [False] * 2 + [True]
     reg.inputs.winsorize_lower_quantile = 0.005
@@ -503,8 +464,7 @@ def create_reg_workflow(name='registration'):
     reg.inputs.num_threads = 4
     reg.plugin_args = {'sbatch_args': '-c%d' % 4}
     register.connect(stripper, 'out_file', reg, 'moving_image')
-    register.connect(inputnode,'target_image', reg,'fixed_image')
-
+    register.connect(inputnode, 'target_image', reg, 'fixed_image')
 
     """
     Concatenate the affine and ants transforms into a list
@@ -514,7 +474,6 @@ def create_reg_workflow(name='registration'):
     register.connect(convert2itk, 'itk_transform', merge, 'in2')
     register.connect(reg, 'composite_transform', merge, 'in1')
 
-
     """
     Transform the mean image. First to anatomical and then to target
     """
@@ -523,16 +482,15 @@ def create_reg_workflow(name='registration'):
     warpmean.inputs.input_image_type = 3
     warpmean.inputs.interpolation = 'Linear'
     warpmean.inputs.invert_transform_flags = [False, False]
-    warpmean.inputs.terminal_output = 'file'
+    warpmean.terminal_output = 'file'
     warpmean.inputs.args = '--float'
     warpmean.inputs.num_threads = 4
     warpmean.plugin_args = {'sbatch_args': '-c%d' % 4}
 
-    register.connect(inputnode,'target_image', warpmean,'reference_image')
+    register.connect(inputnode, 'target_image', warpmean, 'reference_image')
     register.connect(inputnode, 'mean_image', warpmean, 'input_image')
     register.connect(merge, 'out', warpmean, 'transforms')
 
-
     """
     Assign all the output files
     """
@@ -584,7 +542,7 @@ def create_workflow(files,
                           iterfield=['in_file', 'run'],
                           name='rename')
     name_unique.inputs.keep_ext = True
-    name_unique.inputs.run = range(1, len(files) + 1)
+    name_unique.inputs.run = list(range(1, len(files) + 1))
     name_unique.inputs.in_file = files
 
     realign = Node(nipy.SpaceTimeRealigner(), name="spacetime_realign")
@@ -593,17 +551,12 @@ def create_workflow(files,
     realign.inputs.slice_info = 2
     realign.plugin_args = {'sbatch_args': '-c%d' % 4}
 
-
-    # Comute TSNR on realigned data regressing polynomials upto order 2
+    # Compute TSNR on realigned data regressing polynomials up to order 2
     tsnr = MapNode(TSNR(regress_poly=2), iterfield=['in_file'], name='tsnr')
-    wf.connect(realign,"out_file", tsnr, "in_file")
+    wf.connect(realign, "out_file", tsnr, "in_file")
 
     # Compute the median image across runs
-    calc_median = Node(Function(input_names=['in_files'],
-                                output_names=['median_file'],
-                                function=median,
-                                imports=imports),
-                       name='median')
+    calc_median = Node(CalculateMedian(), name='median')
     wf.connect(tsnr, 'detrended_file', calc_median, 'in_files')
 
     """Segment and Register
@@ -637,7 +590,6 @@ def create_workflow(files,
     art.inputs.mask_type = 'spm_global'
     art.inputs.parameter_source = 'NiPy'
 
-
     """Here we are connecting all the nodes together. Notice that we add the merge node only if you choose
     to use 4D. Also `get_vox_dims` function is passed along the input volume of normalise to set the optimal
     voxel sizes.
@@ -686,7 +638,6 @@ def create_workflow(files,
     wf.connect(art, 'norm_files', createfilter1, 'comp_norm')
     wf.connect(art, 'outlier_files', createfilter1, 'outliers')
 
-
     filter1 = MapNode(fsl.GLM(out_f_name='F_mcart.nii.gz',
                               out_pf_name='pF_mcart.nii.gz',
                               demean=True),
@@ -698,15 +649,10 @@ def create_workflow(files,
                filter1, 'out_res_name')
     wf.connect(createfilter1, 'out_files', filter1, 'design')
 
-
-    createfilter2 = MapNode(Function(input_names=['realigned_file', 'mask_file',
-                                                  'num_components',
-                                                  'extra_regressors'],
-                                     output_names=['out_files'],
-                                     function=extract_noise_components,
-                                     imports=imports),
+    createfilter2 = MapNode(ACompCor(),
                             iterfield=['realigned_file', 'extra_regressors'],
                             name='makecompcorrfilter')
+    createfilter2.inputs.components_file = 'noise_components.txt'
     createfilter2.inputs.num_components = num_components
 
     wf.connect(createfilter1, 'out_files', createfilter2, 'extra_regressors')
@@ -714,7 +660,6 @@ def create_workflow(files,
     wf.connect(registration, ('outputspec.segmentation_files', selectindex, [0, 2]),
                createfilter2, 'mask_file')
 
-
     filter2 = MapNode(fsl.GLM(out_f_name='F.nii.gz',
                               out_pf_name='pF.nii.gz',
                               demean=True),
@@ -723,16 +668,16 @@ def create_workflow(files,
     wf.connect(filter1, 'out_res', filter2, 'in_file')
     wf.connect(filter1, ('out_res', rename, '_cleaned'),
                filter2, 'out_res_name')
-    wf.connect(createfilter2, 'out_files', filter2, 'design')
+    wf.connect(createfilter2, 'components_file', filter2, 'design')
     wf.connect(mask, 'mask_file', filter2, 'mask')
 
     bandpass = Node(Function(input_names=['files', 'lowpass_freq',
-                                           'highpass_freq', 'fs'],
-                              output_names=['out_files'],
-                              function=bandpass_filter,
-                              imports=imports),
-                     name='bandpass_unsmooth')
-    bandpass.inputs.fs = 1./TR
+                                          'highpass_freq', 'fs'],
+                             output_names=['out_files'],
+                             function=bandpass_filter,
+                             imports=imports),
+                    name='bandpass_unsmooth')
+    bandpass.inputs.fs = 1. / TR
     bandpass.inputs.highpass_freq = highpass_freq
     bandpass.inputs.lowpass_freq = lowpass_freq
     wf.connect(filter2, 'out_res', bandpass, 'files')
@@ -759,7 +704,7 @@ def create_workflow(files,
     warpall.inputs.input_image_type = 3
     warpall.inputs.interpolation = 'Linear'
     warpall.inputs.invert_transform_flags = [False, False]
-    warpall.inputs.terminal_output = 'file'
+    warpall.terminal_output = 'file'
     warpall.inputs.reference_image = target_file
     warpall.inputs.args = '--float'
     warpall.inputs.num_threads = 2
@@ -791,9 +736,9 @@ def create_workflow(files,
                           iterfield=['in_file', 'summary_file',
                                      'avgwf_txt_file'],
                           name='aparc_ts')
-    sampleaparc.inputs.segment_id = ([8] + range(10, 14) + [17, 18, 26, 47] +
-                                     range(49, 55) + [58] + range(1001, 1036) +
-                                     range(2001, 2036))
+    sampleaparc.inputs.segment_id = ([8] + list(range(10, 14)) + [17, 18, 26, 47] +
+                                     list(range(49, 55)) + [58] + list(range(1001, 1036)) +
+                                     list(range(2001, 2036)))
 
     wf.connect(registration, 'outputspec.aparc',
                sampleaparc, 'segmentation_file')
@@ -808,7 +753,7 @@ def create_workflow(files,
         out_names = []
         for filename in files:
             path, name, _ = split_filename(filename)
-            out_names.append(os.path.join(path,name + suffix))
+            out_names.append(os.path.join(path, name + suffix))
         return list_to_filename(out_names)
 
     wf.connect(collector, ('out', get_names, '_avgwf.txt'),
@@ -829,7 +774,7 @@ def create_workflow(files,
     samplerlh.inputs.sampling_units = "frac"
     samplerlh.inputs.interp_method = "trilinear"
     samplerlh.inputs.smooth_surf = surf_fwhm
-    #samplerlh.inputs.cortex_mask = True
+    # samplerlh.inputs.cortex_mask = True
     samplerlh.inputs.out_type = 'niigz'
     samplerlh.inputs.subjects_dir = subjects_dir
 
@@ -863,8 +808,8 @@ def create_workflow(files,
                               imports=imports),
                      iterfield=['timeseries_file'],
                      name='getsubcortts')
-    ts2txt.inputs.indices = [8] + range(10, 14) + [17, 18, 26, 47] +\
-                            range(49, 55) + [58]
+    ts2txt.inputs.indices = [8] + list(range(10, 14)) + [17, 18, 26, 47] +\
+        list(range(49, 55)) + [58]
     ts2txt.inputs.label_file = \
         os.path.abspath(('OASIS-TRT-20_jointfusion_DKT31_CMA_labels_in_MNI152_'
                          '2mm_v2.nii.gz'))
@@ -876,13 +821,13 @@ def create_workflow(files,
                      ('_filtermotart_cleaned_bp_trans_masked', ''),
                      ('_filtermotart_cleaned_bp', ''),
                      ]
-    substitutions += [("_smooth%d" % i,"") for i in range(11)[::-1]]
-    substitutions += [("_ts_masker%d" % i,"") for i in range(11)[::-1]]
-    substitutions += [("_getsubcortts%d" % i,"") for i in range(11)[::-1]]
-    substitutions += [("_combiner%d" % i,"") for i in range(11)[::-1]]
-    substitutions += [("_filtermotion%d" % i,"") for i in range(11)[::-1]]
-    substitutions += [("_filter_noise_nosmooth%d" % i,"") for i in range(11)[::-1]]
-    substitutions += [("_makecompcorfilter%d" % i,"") for i in range(11)[::-1]]
+    substitutions += [("_smooth%d" % i, "") for i in range(11)[::-1]]
+    substitutions += [("_ts_masker%d" % i, "") for i in range(11)[::-1]]
+    substitutions += [("_getsubcortts%d" % i, "") for i in range(11)[::-1]]
+    substitutions += [("_combiner%d" % i, "") for i in range(11)[::-1]]
+    substitutions += [("_filtermotion%d" % i, "") for i in range(11)[::-1]]
+    substitutions += [("_filter_noise_nosmooth%d" % i, "") for i in range(11)[::-1]]
+    substitutions += [("_makecompcorfilter%d" % i, "") for i in range(11)[::-1]]
     substitutions += [("_get_aparc_tsnr%d/" % i, "run%d_" % (i + 1)) for i in range(11)[::-1]]
 
     substitutions += [("T1_out_brain_pve_0_maths_warped", "compcor_csf"),
@@ -907,7 +852,7 @@ def create_workflow(files,
     datasink.inputs.base_directory = sink_directory
     datasink.inputs.container = subject_id
     datasink.inputs.substitutions = substitutions
-    datasink.inputs.regexp_substitutions = regex_subs #(r'(/_.*(\d+/))', r'/run\2')
+    datasink.inputs.regexp_substitutions = regex_subs  # (r'(/_.*(\d+/))', r'/run\2')
     wf.connect(realign, 'par_file', datasink, 'resting.qa.motion')
     wf.connect(art, 'norm_files', datasink, 'resting.qa.art.@norm')
     wf.connect(art, 'intensity_files', datasink, 'resting.qa.art.@intensity')
@@ -929,7 +874,7 @@ def create_workflow(files,
     wf.connect(smooth, 'out_file', datasink, 'resting.timeseries.@smoothed')
     wf.connect(createfilter1, 'out_files',
                datasink, 'resting.regress.@regressors')
-    wf.connect(createfilter2, 'out_files',
+    wf.connect(createfilter2, 'components_file',
                datasink, 'resting.regress.@compcorr')
     wf.connect(maskts, 'out_file', datasink, 'resting.timeseries.target')
     wf.connect(sampleaparc, 'summary_file',
@@ -943,7 +888,7 @@ def create_workflow(files,
     datasink2.inputs.base_directory = sink_directory
     datasink2.inputs.container = subject_id
     datasink2.inputs.substitutions = substitutions
-    datasink2.inputs.regexp_substitutions = regex_subs #(r'(/_.*(\d+/))', r'/run\2')
+    datasink2.inputs.regexp_substitutions = regex_subs  # (r'(/_.*(\d+/))', r'/run\2')
     wf.connect(combiner, 'out_file',
                datasink2, 'resting.parcellations.grayo.@surface')
     return wf
@@ -953,12 +898,13 @@ def create_workflow(files,
 Creates the full workflow including getting information from dicom files
 """
 
+
 def create_resting_workflow(args, name=None):
     TR = args.TR
     slice_times = args.slice_times
     if args.dicom_file:
         TR, slice_times, slice_thickness = get_info(args.dicom_file)
-        slice_times = (np.array(slice_times)/1000.).tolist()
+        slice_times = (np.array(slice_times) / 1000.).tolist()
 
     if name is None:
         name = 'resting_' + args.subject_id
