@@ -12,6 +12,11 @@ create a template out of multiple T1 volumes.
 1. Tell python where to find the appropriate functions.
 """
 
+from __future__ import print_function, unicode_literals
+from builtins import open
+from future import standard_library
+standard_library.install_aliases()
+
 import os
 import nipype.interfaces.utility as util
 import nipype.interfaces.ants as ants
@@ -24,27 +29,29 @@ from nipype.workflows.smri.ants import ANTSTemplateBuildSingleIterationWF
 2. Download T1 volumes into home directory
 """
 
-import urllib2
-homeDir=os.getenv("HOME")
-requestedPath=os.path.join(homeDir,'nipypeTestPath')
-mydatadir=os.path.realpath(requestedPath)
+import urllib.request
+import urllib.error
+import urllib.parse
+homeDir = os.getenv("HOME")
+requestedPath = os.path.join(homeDir, 'nipypeTestPath')
+mydatadir = os.path.realpath(requestedPath)
 if not os.path.exists(mydatadir):
     os.makedirs(mydatadir)
-print mydatadir
+print(mydatadir)
 
-MyFileURLs=[
-           ('http://slicer.kitware.com/midas3/download?bitstream=13121','01_T1_half.nii.gz'),
-           ('http://slicer.kitware.com/midas3/download?bitstream=13122','02_T1_half.nii.gz'),
-           ('http://slicer.kitware.com/midas3/download?bitstream=13124','03_T1_half.nii.gz'),
-           ('http://slicer.kitware.com/midas3/download?bitstream=13128','01_T1_inv_half.nii.gz'),
-           ('http://slicer.kitware.com/midas3/download?bitstream=13123','02_T1_inv_half.nii.gz'),
-           ('http://slicer.kitware.com/midas3/download?bitstream=13125','03_T1_inv_half.nii.gz'),
-           ]
+MyFileURLs = [
+    ('http://slicer.kitware.com/midas3/download?bitstream=13121', '01_T1_half.nii.gz'),
+    ('http://slicer.kitware.com/midas3/download?bitstream=13122', '02_T1_half.nii.gz'),
+    ('http://slicer.kitware.com/midas3/download?bitstream=13124', '03_T1_half.nii.gz'),
+    ('http://slicer.kitware.com/midas3/download?bitstream=13128', '01_T1_inv_half.nii.gz'),
+    ('http://slicer.kitware.com/midas3/download?bitstream=13123', '02_T1_inv_half.nii.gz'),
+    ('http://slicer.kitware.com/midas3/download?bitstream=13125', '03_T1_inv_half.nii.gz'),
+]
 for tt in MyFileURLs:
-    myURL=tt[0]
-    localFilename=os.path.join(mydatadir,tt[1])
+    myURL = tt[0]
+    localFilename = os.path.join(mydatadir, tt[1])
     if not os.path.exists(localFilename):
-        remotefile = urllib2.urlopen(myURL)
+        remotefile = urllib.request.urlopen(myURL)
 
         localFile = open(localFilename, 'wb')
         localFile.write(remotefile.read())
@@ -53,15 +60,15 @@ for tt in MyFileURLs:
     else:
         print("File previously downloaded {0}".format(localFilename))
 
-input_images=[
-os.path.join(mydatadir,'01_T1_half.nii.gz'),
-os.path.join(mydatadir,'02_T1_half.nii.gz'),
-os.path.join(mydatadir,'03_T1_half.nii.gz')
+input_images = [
+    os.path.join(mydatadir, '01_T1_half.nii.gz'),
+    os.path.join(mydatadir, '02_T1_half.nii.gz'),
+    os.path.join(mydatadir, '03_T1_half.nii.gz')
 ]
-input_passive_images=[
-{'INV_T1':os.path.join(mydatadir,'01_T1_inv_half.nii.gz')},
-{'INV_T1':os.path.join(mydatadir,'02_T1_inv_half.nii.gz')},
-{'INV_T1':os.path.join(mydatadir,'03_T1_inv_half.nii.gz')}
+input_passive_images = [
+    {'INV_T1': os.path.join(mydatadir, '01_T1_inv_half.nii.gz')},
+    {'INV_T1': os.path.join(mydatadir, '02_T1_inv_half.nii.gz')},
+    {'INV_T1': os.path.join(mydatadir, '03_T1_inv_half.nii.gz')}
 ]
 
 
@@ -69,26 +76,25 @@ input_passive_images=[
 3. Define the workflow and its working directory
 """
 
-tbuilder=pe.Workflow(name="ANTSTemplateBuilder")
-tbuilder.base_dir=requestedPath
+tbuilder = pe.Workflow(name="ANTSTemplateBuilder")
+tbuilder.base_dir = requestedPath
 
 """
 4. Define data sources. In real life these would be replace by DataGrabbers
 """
 
-datasource = pe.Node(interface=util.IdentityInterface(fields=
-                    ['imageList', 'passiveImagesDictionariesList']),
-                    run_without_submitting=True,
-                    name='InputImages' )
-datasource.inputs.imageList=input_images
-datasource.inputs.passiveImagesDictionariesList=input_passive_images
+datasource = pe.Node(interface=util.IdentityInterface(fields=['imageList', 'passiveImagesDictionariesList']),
+                     run_without_submitting=True,
+                     name='InputImages')
+datasource.inputs.imageList = input_images
+datasource.inputs.passiveImagesDictionariesList = input_passive_images
 datasource.inputs.sort_filelist = True
 
 """
 5. Template is initialized by a simple average
 """
 
-initAvg = pe.Node(interface=ants.AverageImages(), name ='initAvg')
+initAvg = pe.Node(interface=ants.AverageImages(), name='initAvg')
 initAvg.inputs.dimension = 3
 initAvg.inputs.normalize = True
 
@@ -98,7 +104,7 @@ tbuilder.connect(datasource, "imageList", initAvg, "images")
 6. Define the first iteration of template building
 """
 
-buildTemplateIteration1=ANTSTemplateBuildSingleIterationWF('iteration01')
+buildTemplateIteration1 = ANTSTemplateBuildSingleIterationWF('iteration01')
 tbuilder.connect(initAvg, 'output_average_image', buildTemplateIteration1, 'inputspec.fixed_image')
 tbuilder.connect(datasource, 'imageList', buildTemplateIteration1, 'inputspec.images')
 tbuilder.connect(datasource, 'passiveImagesDictionariesList', buildTemplateIteration1, 'inputspec.ListOfPassiveImagesDictionaries')
@@ -119,9 +125,9 @@ tbuilder.connect(datasource, 'passiveImagesDictionariesList', buildTemplateItera
 datasink = pe.Node(io.DataSink(), name="datasink")
 datasink.inputs.base_directory = os.path.join(requestedPath, "results")
 
-tbuilder.connect(buildTemplateIteration2, 'outputspec.template',datasink,'PrimaryTemplate')
-tbuilder.connect(buildTemplateIteration2, 'outputspec.passive_deformed_templates',datasink,'PassiveTemplate')
-tbuilder.connect(initAvg, 'output_average_image', datasink,'PreRegisterAverage')
+tbuilder.connect(buildTemplateIteration2, 'outputspec.template', datasink, 'PrimaryTemplate')
+tbuilder.connect(buildTemplateIteration2, 'outputspec.passive_deformed_templates', datasink, 'PassiveTemplate')
+tbuilder.connect(initAvg, 'output_average_image', datasink, 'PreRegisterAverage')
 
 """
 8. Run the workflow
