@@ -96,9 +96,12 @@ Using interfaces
 Having interfaces allows us to use third party software (like FSL BET) as function. Look how simple it is.
 """
 
+from __future__ import print_function
+from builtins import str
+
 import nipype.interfaces.fsl as fsl
 result = fsl.BET(in_file='data/s1/struct.nii').run()
-print result
+print(result)
 
 """
 Running a single program is not much of a breakthrough. Lets run motion correction followed by smoothing
@@ -129,10 +132,10 @@ motion_correct = pe.Node(interface=fsl.MCFLIRT(in_file=os.path.abspath('data/s1/
 smooth = pe.Node(interface=fsl.Smooth(fwhm=6), name="smooth")
 
 motion_correct_and_smooth = pe.Workflow(name="motion_correct_and_smooth")
-motion_correct_and_smooth.base_dir = os.path.abspath('.') # define where will be the root folder for the workflow
+motion_correct_and_smooth.base_dir = os.path.abspath('.')  # define where will be the root folder for the workflow
 motion_correct_and_smooth.connect([
-                                   (motion_correct, smooth, [('out_file', 'in_file')])
-                                   ])
+    (motion_correct, smooth, [('out_file', 'in_file')])
+])
 # we are connecting 'out_file' output of motion_correct to 'in_file' input of smooth
 motion_correct_and_smooth.run()
 
@@ -152,8 +155,8 @@ subtract.inputs.op_string = "-sub"
 demean = pe.Workflow(name="demean")
 demean.base_dir = os.path.abspath('.')
 demean.connect([
-                (calc_mean, subtract, [('out_file', 'in_file2')])
-                ])
+    (calc_mean, subtract, [('out_file', 'in_file2')])
+])
 
 demean.inputs.calc_mean.in_file = os.path.abspath('data/s1/f3.nii')
 demean.inputs.subtract.in_file = os.path.abspath('data/s1/f3.nii')
@@ -210,13 +213,13 @@ import nipype.interfaces.io as nio
 
 preproc.inputs.inputspec.func = os.path.abspath('data/s1/f3.nii')
 preproc.inputs.inputspec.struct = os.path.abspath('data/s1/struct.nii')
-datasink = pe.Node(interface=nio.DataSink(),name='sinker')
+datasink = pe.Node(interface=nio.DataSink(), name='sinker')
 preprocess = pe.Workflow(name='preprocout')
 preprocess.base_dir = os.path.abspath('.')
 preprocess.connect([
-                    (preproc, datasink, [('meanfunc2.out_file', 'meanfunc'),
-                                         ('maskfunc3.out_file', 'funcruns')])
-                    ])
+    (preproc, datasink, [('meanfunc2.out_file', 'meanfunc'),
+                         ('maskfunc3.out_file', 'funcruns')])
+])
 preprocess.run()
 
 """
@@ -231,20 +234,20 @@ datasource1 = nio.DataGrabber()
 datasource1.inputs.template = 'data/s1/f3.nii'
 datasource1.inputs.sort_filelist = True
 results = datasource1.run()
-print results.outputs
+print(results.outputs)
 
 datasource2 = nio.DataGrabber()
 datasource2.inputs.template = 'data/s*/f*.nii'
 datasource2.inputs.sort_filelist = True
 results = datasource2.run()
-print results.outputs
+print(results.outputs)
 
 datasource3 = nio.DataGrabber(infields=['run'])
 datasource3.inputs.template = 'data/s1/f%d.nii'
 datasource3.inputs.sort_filelist = True
 datasource3.inputs.run = [3, 7]
 results = datasource3.run()
-print results.outputs
+print(results.outputs)
 
 datasource4 = nio.DataGrabber(infields=['subject_id', 'run'])
 datasource4.inputs.template = 'data/%s/f%d.nii'
@@ -252,7 +255,7 @@ datasource4.inputs.sort_filelist = True
 datasource4.inputs.run = [3, 7]
 datasource4.inputs.subject_id = ['s1', 's3']
 results = datasource4.run()
-print results.outputs
+print(results.outputs)
 
 """
 Iterables
@@ -270,7 +273,7 @@ infosource.iterables = ('subject_id', ['s1', 's3'])
 datasource = pe.Node(nio.DataGrabber(infields=['subject_id'], outfields=['func', 'struct']), name="datasource")
 datasource.inputs.template = '%s/%s.nii'
 datasource.inputs.base_directory = os.path.abspath('data')
-datasource.inputs.template_args = dict(func=[['subject_id','f3']], struct=[['subject_id','struct']])
+datasource.inputs.template_args = dict(func=[['subject_id', 'f3']], struct=[['subject_id', 'struct']])
 datasource.inputs.sort_filelist = True
 
 my_workflow = pe.Workflow(name="my_workflow")
@@ -278,7 +281,7 @@ my_workflow.base_dir = os.path.abspath('.')
 
 my_workflow.connect([(infosource, datasource, [('subject_id', 'subject_id')]),
                      (datasource, preproc, [('func', 'inputspec.func'),
-                                          ('struct', 'inputspec.struct')])])
+                                            ('struct', 'inputspec.struct')])])
 my_workflow.run()
 
 
@@ -288,8 +291,8 @@ and we can change a node attribute and run it again
 """
 
 smoothnode = my_workflow.get_node('preproc.smooth')
-assert(str(smoothnode)=='preproc.smooth')
-smoothnode.iterables = ('fwhm', [5.,10.])
+assert(str(smoothnode) == 'preproc.smooth')
+smoothnode.iterables = ('fwhm', [5., 10.])
 my_workflow.run()
 
 """
