@@ -1,35 +1,48 @@
+# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-'''
+"""
 Miscellaneous algorithms for 2D contours and 3D triangularized meshes handling
 
-    Change directory to provide relative paths for doctests
+  .. testsetup::
+    # Change directory to provide relative paths for doctests
     >>> import os
-    >>> filepath = os.path.dirname( os.path.realpath( __file__ ) )
+    >>> filepath = os.path.dirname(os.path.realpath( __file__ ))
     >>> datadir = os.path.realpath(os.path.join(filepath, '../testing/data'))
     >>> os.chdir(datadir)
 
-'''
-
+"""
+from __future__ import print_function, division, unicode_literals, absolute_import
+from builtins import zip, str, bytes
 
+import os.path as op
 import numpy as np
 from numpy import linalg as nla
-import os.path as op
-from ..external import six
 
 from .. import logging
-
 from ..interfaces.base import (BaseInterface, traits, TraitedSpec, File,
                                BaseInterfaceInputSpec)
-from warnings import warn
-iflogger = logging.getLogger('interface')
+from ..interfaces.vtkbase import tvtk
+from ..interfaces import vtkbase as VTKInfo
+IFLOGGER = logging.getLogger('interface')
+
+
+class TVTKBaseInterface(BaseInterface):
+    """ A base class for interfaces using VTK """
+
+    _redirect_x = True
+
+    def __init__(self, **inputs):
+        if VTKInfo.no_tvtk():
+            raise ImportError('This interface requires tvtk to run.')
+        super(TVTKBaseInterface, self).__init__(**inputs)
 
 
 class WarpPointsInputSpec(BaseInterfaceInputSpec):
     points = File(exists=True, mandatory=True,
-                  desc=('file containing the point set'))
+                  desc='file containing the point set')
     warp = File(exists=True, mandatory=True,
-                desc=('dense deformation field to be applied'))
+                desc='dense deformation field to be applied')
     interp = traits.Enum('cubic', 'nearest', 'linear', usedefault=True,
                          mandatory=True, desc='interpolation')
     out_points = File(name_source='points', name_template='%s_warped',
@@ -41,8 +54,7 @@ class WarpPointsOutputSpec(TraitedSpec):
     out_points = File(desc='the warped point set')
 
 
-class WarpPoints(BaseInterface):
-
+class WarpPoints(TVTKBaseInterface):
     """
     Applies a displacement field to a point set given in vtk format.
     Any discrete deformation field, given in physical coordinates and
@@ -50,27 +62,24 @@ class WarpPoints(BaseInterface):
     ``warp`` file. FSL interfaces are compatible, for instance any
     field computed with :class:`nipype.interfaces.fsl.utils.ConvertWarp`.
 
-    Example
-    -------
+    Example::
+
+        from nipype.algorithms.mesh import WarpPoints
+        wp = WarpPoints()
+        wp.inputs.points = 'surf1.vtk'
+        wp.inputs.warp = 'warpfield.nii'
+        res = wp.run()
 
-    >>> from nipype.algorithms.mesh import WarpPoints
-    >>> wp = WarpPoints()
-    >>> wp.inputs.points = 'surf1.vtk'
-    >>> wp.inputs.warp = 'warpfield.nii'
-    >>> res = wp.run() # doctest: +SKIP
     """
     input_spec = WarpPointsInputSpec
     output_spec = WarpPointsOutputSpec
-    _redirect_x = True
 
     def _gen_fname(self, in_file, suffix='generated', ext=None):
-        import os.path as op
-
         fname, fext = op.splitext(op.basename(in_file))
 
         if fext == '.gz':
             fname, fext2 = op.splitext(fname)
-            fext = fext2+fext
+            fext = fext2 + fext
 
         if ext is None:
             ext = fext
@@ -80,43 +89,21 @@ class WarpPoints(BaseInterface):
         return op.abspath('%s_%s.%s' % (fname, suffix, ext))
 
     def _run_interface(self, runtime):
-        vtk_major = 6
-        try:
-            import vtk
-            vtk_major = vtk.VTK_MAJOR_VERSION
-        except ImportError:
-            iflogger.warn(('python-vtk could not be imported'))
-
-        try:
-            from tvtk.api import tvtk
-        except ImportError:
-            raise ImportError('Interface requires tvtk')
-
-        try:
-            from enthought.etsconfig.api import ETSConfig
-            ETSConfig.toolkit = 'null'
-        except ImportError:
-            iflogger.warn(('ETS toolkit could not be imported'))
-        except ValueError:
-            iflogger.warn(('ETS toolkit could not be set to null'))
-
         import nibabel as nb
-        import numpy as np
         from scipy import ndimage
 
         r = tvtk.PolyDataReader(file_name=self.inputs.points)
         r.update()
-        mesh = r.output
+        mesh = VTKInfo.vtk_output(r)
         points = np.array(mesh.points)
         warp_dims = nb.funcs.four_to_three(nb.load(self.inputs.warp))
 
-        affine = warp_dims[0].get_affine()
-        voxsize = warp_dims[0].get_header().get_zooms()
+        affine = warp_dims[0].affine
+        # voxsize = warp_dims[0].header.get_zooms()
         vox2ras = affine[0:3, 0:3]
         ras2vox = np.linalg.inv(vox2ras)
         origin = affine[0:3, 3]
-        voxpoints = np.array([np.dot(ras2vox,
-                                     (p-origin)) for p in points])
+        voxpoints = np.array([np.dot(ras2vox, (p - origin)) for p in points])
 
         warps = []
         for axis in warp_dims:
@@ -131,24 +118,17 @@ class WarpPoints(BaseInterface):
             warps.append(warp)
 
         disps = np.squeeze(np.dstack(warps))
-        newpoints = [p+d for p, d in zip(points, disps)]
+        newpoints = [p + d for p, d in zip(points, disps)]
         mesh.points = newpoints
         w = tvtk.PolyDataWriter()
-        if vtk_major <= 5:
-            w.input = mesh
-        else:
-            w.set_input_data_object(mesh)
-
-        w.file_name = self._gen_fname(self.inputs.points,
-                                      suffix='warped',
-                                      ext='.vtk')
+        VTKInfo.configure_input_data(w, mesh)
+        w.file_name = self._gen_fname(self.inputs.points, suffix='warped', ext='.vtk')
         w.write()
         return runtime
 
     def _list_outputs(self):
         outputs = self._outputs().get()
-        outputs['out_points'] = self._gen_fname(self.inputs.points,
-                                                suffix='warped',
+        outputs['out_points'] = self._gen_fname(self.inputs.points, suffix='warped',
                                                 ext='.vtk')
         return outputs
 
@@ -162,7 +142,7 @@ class ComputeMeshWarpInputSpec(BaseInterfaceInputSpec):
                     desc=('Test surface (vtk format) from which compute '
                           'distance.'))
     metric = traits.Enum('euclidean', 'sqeuclidean', usedefault=True,
-                         desc=('norm used to report distance'))
+                         desc='norm used to report distance')
     weighting = traits.Enum(
         'none', 'area', usedefault=True,
         desc=('"none": no weighting is performed, surface": edge distance is '
@@ -182,8 +162,7 @@ class ComputeMeshWarpOutputSpec(TraitedSpec):
                     desc='numpy file keeping computed distances and weights')
 
 
-class ComputeMeshWarp(BaseInterface):
-
+class ComputeMeshWarp(TVTKBaseInterface):
     """
     Calculates a the vertex-wise warping to get surface2 from surface1.
     It also reports the average distance of vertices, using the norm specified
@@ -194,20 +173,18 @@ class ComputeMeshWarp(BaseInterface):
       A point-to-point correspondence between surfaces is required
 
 
-    Example
-    -------
+    Example::
 
-    >>> import nipype.algorithms.mesh as m
-    >>> dist = m.ComputeMeshWarp()
-    >>> dist.inputs.surface1 = 'surf1.vtk'
-    >>> dist.inputs.surface2 = 'surf2.vtk'
-    >>> res = dist.run() # doctest: +SKIP
+        import nipype.algorithms.mesh as m
+        dist = m.ComputeMeshWarp()
+        dist.inputs.surface1 = 'surf1.vtk'
+        dist.inputs.surface2 = 'surf2.vtk'
+        res = dist.run()
 
     """
 
     input_spec = ComputeMeshWarpInputSpec
     output_spec = ComputeMeshWarpOutputSpec
-    _redirect_x = True
 
     def _triangle_area(self, A, B, C):
         A = np.array(A)
@@ -220,23 +197,10 @@ class ComputeMeshWarp(BaseInterface):
         return area
 
     def _run_interface(self, runtime):
-        try:
-            from tvtk.api import tvtk
-        except ImportError:
-            raise ImportError('Interface ComputeMeshWarp requires tvtk')
-
-        try:
-            from enthought.etsconfig.api import ETSConfig
-            ETSConfig.toolkit = 'null'
-        except ImportError:
-            iflogger.warn(('ETS toolkit could not be imported'))
-        except ValueError:
-            iflogger.warn(('ETS toolkit is already set'))
-
         r1 = tvtk.PolyDataReader(file_name=self.inputs.surface1)
         r2 = tvtk.PolyDataReader(file_name=self.inputs.surface2)
-        vtk1 = r1.output
-        vtk2 = r2.output
+        vtk1 = VTKInfo.vtk_output(r1)
+        vtk2 = VTKInfo.vtk_output(r2)
         r1.update()
         r2.update()
         assert(len(vtk1.points) == len(vtk2.points))
@@ -253,9 +217,9 @@ class ComputeMeshWarp(BaseInterface):
             errvector = np.apply_along_axis(nla.norm, 1, diff)
 
         if self.inputs.metric == 'sqeuclidean':
-            errvector = errvector ** 2
+            errvector **= 2
 
-        if (self.inputs.weighting == 'area'):
+        if self.inputs.weighting == 'area':
             faces = vtk1.polys.to_array().reshape(-1, 4).astype(int)[:, 1:]
 
             for i, p1 in enumerate(points2):
@@ -280,7 +244,7 @@ class ComputeMeshWarp(BaseInterface):
         out_mesh.point_data.vectors.name = 'warpings'
         writer = tvtk.PolyDataWriter(
             file_name=op.abspath(self.inputs.out_warp))
-        writer.set_input_data(out_mesh)
+        VTKInfo.configure_input_data(writer, out_mesh)
         writer.write()
 
         self._distance = np.average(errvector, weights=weights)
@@ -303,10 +267,10 @@ class MeshWarpMathsInputSpec(BaseInterfaceInputSpec):
 
     operator = traits.Either(
         float_trait, File(exists=True), default=1.0, mandatory=True,
-        desc=('image, float or tuple of floats to act as operator'))
+        desc='image, float or tuple of floats to act as operator')
 
     operation = traits.Enum('sum', 'sub', 'mul', 'div', usedefault=True,
-                            desc=('operation to be performed'))
+                            desc='operation to be performed')
 
     out_warp = File('warp_maths.vtk', usedefault=True,
                     desc='vtk file based on in_surf and warpings mapping it '
@@ -322,8 +286,7 @@ class MeshWarpMathsOutputSpec(TraitedSpec):
                     desc='vtk with surface warped')
 
 
-class MeshWarpMaths(BaseInterface):
-
+class MeshWarpMaths(TVTKBaseInterface):
     """
     Performs the most basic mathematical operations on the warping field
     defined at each vertex of the input surface. A surface with scalar
@@ -334,50 +297,35 @@ class MeshWarpMaths(BaseInterface):
       A point-to-point correspondence between surfaces is required
 
 
-    Example
-    -------
+    Example::
 
-    >>> import nipype.algorithms.mesh as m
-    >>> mmath = m.MeshWarpMaths()
-    >>> mmath.inputs.in_surf = 'surf1.vtk'
-    >>> mmath.inputs.operator = 'surf2.vtk'
-    >>> mmath.inputs.operation = 'mul'
-    >>> res = mmath.run() # doctest: +SKIP
+        import nipype.algorithms.mesh as m
+        mmath = m.MeshWarpMaths()
+        mmath.inputs.in_surf = 'surf1.vtk'
+        mmath.inputs.operator = 'surf2.vtk'
+        mmath.inputs.operation = 'mul'
+        res = mmath.run()
 
     """
 
     input_spec = MeshWarpMathsInputSpec
     output_spec = MeshWarpMathsOutputSpec
-    _redirect_x = True
 
     def _run_interface(self, runtime):
-        try:
-            from tvtk.api import tvtk
-        except ImportError:
-            raise ImportError('Interface ComputeMeshWarp requires tvtk')
-
-        try:
-            from enthought.etsconfig.api import ETSConfig
-            ETSConfig.toolkit = 'null'
-        except ImportError:
-            iflogger.warn(('ETS toolkit could not be imported'))
-        except ValueError:
-            iflogger.warn(('ETS toolkit is already set'))
-
         r1 = tvtk.PolyDataReader(file_name=self.inputs.in_surf)
-        vtk1 = r1.output
+        vtk1 = VTKInfo.vtk_output(r1)
         r1.update()
         points1 = np.array(vtk1.points)
 
         if vtk1.point_data.vectors is None:
-            raise RuntimeError(('No warping field was found in in_surf'))
+            raise RuntimeError('No warping field was found in in_surf')
 
         operator = self.inputs.operator
         opfield = np.ones_like(points1)
 
-        if isinstance(operator, six.string_types):
+        if isinstance(operator, (str, bytes)):
             r2 = tvtk.PolyDataReader(file_name=self.inputs.surface2)
-            vtk2 = r2.output
+            vtk2 = VTKInfo.vtk_output(r2)
             r2.update()
             assert(len(points1) == len(vtk2.points))
 
@@ -388,7 +336,7 @@ class MeshWarpMaths(BaseInterface):
 
             if opfield is None:
                 raise RuntimeError(
-                    ('No operator values found in operator file'))
+                    'No operator values found in operator file')
 
             opfield = np.array(opfield)
 
@@ -410,18 +358,15 @@ class MeshWarpMaths(BaseInterface):
             warping /= opfield
 
         vtk1.point_data.vectors = warping
-        writer = tvtk.PolyDataWriter(
-            file_name=op.abspath(self.inputs.out_warp))
-        writer.set_input_data(vtk1)
+        writer = tvtk.PolyDataWriter(file_name=op.abspath(self.inputs.out_warp))
+        VTKInfo.configure_input_data(writer, vtk1)
         writer.write()
 
         vtk1.point_data.vectors = None
         vtk1.points = points1 + warping
-        writer = tvtk.PolyDataWriter(
-            file_name=op.abspath(self.inputs.out_file))
-        writer.set_input_data(vtk1)
+        writer = tvtk.PolyDataWriter(file_name=op.abspath(self.inputs.out_file))
+        VTKInfo.configure_input_data(writer, vtk1)
         writer.write()
-
         return runtime
 
     def _list_outputs(self):
@@ -432,7 +377,6 @@ class MeshWarpMaths(BaseInterface):
 
 
 class P2PDistance(ComputeMeshWarp):
-
     """
     Calculates a point-to-point (p2p) distance between two corresponding
     VTK-readable meshes or contours.
@@ -445,6 +389,5 @@ class P2PDistance(ComputeMeshWarp):
 
     def __init__(self, **inputs):
         super(P2PDistance, self).__init__(**inputs)
-        warn(('This interface has been deprecated since 1.0, please use '
-              'ComputeMeshWarp'),
-             DeprecationWarning)
+        IFLOGGER.warn('This interface has been deprecated since 1.0, please use '
+                      'ComputeMeshWarp')
