@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 '''
@@ -11,29 +12,26 @@ measures to evaluate results from other processing units.
     >>> os.chdir(datadir)
 
 '''
+from __future__ import print_function, division, unicode_literals, absolute_import
+from builtins import zip, range
 
 import os
 import os.path as op
 
 import nibabel as nb
 import numpy as np
-from math import floor, ceil
-from scipy.ndimage.morphology import grey_dilation
 from scipy.ndimage.morphology import binary_erosion
 from scipy.spatial.distance import cdist, euclidean, dice, jaccard
 from scipy.ndimage.measurements import center_of_mass, label
-from scipy.special import legendre
-import scipy.io as sio
-import itertools
-import scipy.stats as stats
 
-from .. import logging
+from .. import config, logging
 from ..utils.misc import package_check
 
 from ..interfaces.base import (BaseInterface, traits, TraitedSpec, File,
-                               InputMultiPath, OutputMultiPath,
+                               InputMultiPath,
                                BaseInterfaceInputSpec, isdefined)
-from ..utils.filemanip import fname_presuffix, split_filename
+from ..utils import NUMPY_MMAP
+
 iflogger = logging.getLogger('interface')
 
 
@@ -96,34 +94,34 @@ class Distance(BaseInterface):
         origdata2 = nii2.get_data().astype(np.bool)
         border2 = self._find_border(origdata2)
 
-        set1_coordinates = self._get_coordinates(border1, nii1.get_affine())
+        set1_coordinates = self._get_coordinates(border1, nii1.affine)
 
-        set2_coordinates = self._get_coordinates(border2, nii2.get_affine())
+        set2_coordinates = self._get_coordinates(border2, nii2.affine)
 
         dist_matrix = cdist(set1_coordinates.T, set2_coordinates.T)
         (point1, point2) = np.unravel_index(
             np.argmin(dist_matrix), dist_matrix.shape)
         return (euclidean(set1_coordinates.T[point1, :],
-                set2_coordinates.T[point2, :]),
+                          set2_coordinates.T[point2, :]),
                 set1_coordinates.T[point1, :],
                 set2_coordinates.T[point2, :])
 
     def _eucl_cog(self, nii1, nii2):
-        origdata1 = nii1.get_data().astype(np.bool)
-        cog_t = np.array(center_of_mass(origdata1)).reshape(-1, 1)
+        origdata1 = np.logical_and(nii1.get_data() != 0, np.logical_not(np.isnan(nii1.get_data())))
+        cog_t = np.array(center_of_mass(origdata1.copy())).reshape(-1, 1)
         cog_t = np.vstack((cog_t, np.array([1])))
-        cog_t_coor = np.dot(nii1.get_affine(), cog_t)[:3, :]
+        cog_t_coor = np.dot(nii1.affine, cog_t)[:3, :]
 
-        origdata2 = nii2.get_data().astype(np.bool)
+        origdata2 = np.logical_and(nii2.get_data() != 0, np.logical_not(np.isnan(nii2.get_data())))
         (labeled_data, n_labels) = label(origdata2)
 
         cogs = np.ones((4, n_labels))
 
         for i in range(n_labels):
             cogs[:3, i] = np.array(center_of_mass(origdata2,
-                                   labeled_data, i + 1))
+                                                  labeled_data, i + 1))
 
-        cogs_coor = np.dot(nii2.get_affine(), cogs)[:3, :]
+        cogs_coor = np.dot(nii2.affine, cogs)[:3, :]
 
         dist_matrix = cdist(cog_t_coor.T, cogs_coor.T)
 
@@ -135,11 +133,13 @@ class Distance(BaseInterface):
 
         origdata2 = nii2.get_data().astype(np.bool)
 
-        set1_coordinates = self._get_coordinates(border1, nii1.get_affine())
-        set2_coordinates = self._get_coordinates(origdata2, nii2.get_affine())
+        set1_coordinates = self._get_coordinates(border1, nii1.affine)
+        set2_coordinates = self._get_coordinates(origdata2, nii2.affine)
 
         dist_matrix = cdist(set1_coordinates.T, set2_coordinates.T)
         min_dist_matrix = np.amin(dist_matrix, axis=0)
+        import matplotlib
+        matplotlib.use(config.get('execution', 'matplotlib_backend'))
         import matplotlib.pyplot as plt
         plt.figure()
         plt.hist(min_dist_matrix, 50, normed=1, facecolor='green')
@@ -176,8 +176,8 @@ class Distance(BaseInterface):
         border1 = self._find_border(origdata1)
         border2 = self._find_border(origdata2)
 
-        set1_coordinates = self._get_coordinates(border1, nii1.get_affine())
-        set2_coordinates = self._get_coordinates(border2, nii2.get_affine())
+        set1_coordinates = self._get_coordinates(border1, nii1.affine)
+        set2_coordinates = self._get_coordinates(border2, nii2.affine)
         distances = cdist(set1_coordinates.T, set2_coordinates.T)
         mins = np.concatenate(
             (np.amin(distances, axis=0), np.amin(distances, axis=1)))
@@ -185,8 +185,9 @@ class Distance(BaseInterface):
         return np.max(mins)
 
     def _run_interface(self, runtime):
-        nii1 = nb.load(self.inputs.volume1)
-        nii2 = nb.load(self.inputs.volume2)
+        # there is a bug in some scipy ndimage methods that gets tripped by memory mapped objects
+        nii1 = nb.load(self.inputs.volume1, mmap=False)
+        nii2 = nb.load(self.inputs.volume2, mmap=False)
 
         if self.inputs.method == "eucl_min":
             self._distance, self._point1, self._point2 = self._eucl_min(
@@ -287,8 +288,8 @@ class Overlap(BaseInterface):
         scale = 1.0
 
         if self.inputs.vol_units == 'mm':
-            voxvol = nii1.get_header().get_zooms()
-            for i in xrange(nii1.get_data().ndim-1):
+            voxvol = nii1.header.get_zooms()
+            for i in range(nii1.get_data().ndim - 1):
                 scale = scale * voxvol[i]
 
         data1 = nii1.get_data()
@@ -316,13 +317,13 @@ class Overlap(BaseInterface):
 
         for l in labels:
             res.append(self._bool_vec_dissimilarity(data1 == l,
-                       data2 == l, method='jaccard'))
+                                                    data2 == l, method='jaccard'))
             volumes1.append(scale * len(data1[data1 == l]))
             volumes2.append(scale * len(data2[data2 == l]))
 
         results = dict(jaccard=[], dice=[])
         results['jaccard'] = np.array(res)
-        results['dice'] = 2.0*results['jaccard'] / (results['jaccard'] + 1.0)
+        results['dice'] = 2.0 * results['jaccard'] / (results['jaccard'] + 1.0)
 
         weights = np.ones((len(volumes1),), dtype=np.float32)
         if self.inputs.weighting != 'none':
@@ -334,17 +335,17 @@ class Overlap(BaseInterface):
         both_data = np.zeros(data1.shape)
         both_data[(data1 - data2) != 0] = 1
 
-        nb.save(nb.Nifti1Image(both_data, nii1.get_affine(),
-                nii1.get_header()), self.inputs.out_file)
+        nb.save(nb.Nifti1Image(both_data, nii1.affine, nii1.header),
+                self.inputs.out_file)
 
         self._labels = labels
         self._ove_rois = results
-        self._vol_rois = ((np.array(volumes1) - np.array(volumes2)) /
-                          np.array(volumes1))
+        self._vol_rois = (np.array(volumes1) -
+                          np.array(volumes2)) / np.array(volumes1)
 
-        self._dice = round(np.sum(weights*results['dice']), 5)
-        self._jaccard = round(np.sum(weights*results['jaccard']), 5)
-        self._volume = np.sum(weights*self._vol_rois)
+        self._dice = round(np.sum(weights * results['dice']), 5)
+        self._jaccard = round(np.sum(weights * results['jaccard']), 5)
+        self._volume = np.sum(weights * self._vol_rois)
 
         return runtime
 
@@ -363,10 +364,10 @@ class Overlap(BaseInterface):
 
 
 class FuzzyOverlapInputSpec(BaseInterfaceInputSpec):
-    in_ref = InputMultiPath( File(exists=True), mandatory=True,
-                   desc='Reference image. Requires the same dimensions as in_tst.')
-    in_tst = InputMultiPath( File(exists=True), mandatory=True,
-                   desc='Test image. Requires the same dimensions as in_ref.')
+    in_ref = InputMultiPath(File(exists=True), mandatory=True,
+                            desc='Reference image. Requires the same dimensions as in_tst.')
+    in_tst = InputMultiPath(File(exists=True), mandatory=True,
+                            desc='Test image. Requires the same dimensions as in_ref.')
     weighting = traits.Enum('none', 'volume', 'squared_vol', usedefault=True,
                             desc=('\'none\': no class-overlap weighting is '
                                   'performed. \'volume\': computed class-'
@@ -378,11 +379,11 @@ class FuzzyOverlapInputSpec(BaseInterfaceInputSpec):
 
 
 class FuzzyOverlapOutputSpec(TraitedSpec):
-    jaccard = traits.Float( desc='Fuzzy Jaccard Index (fJI), all the classes' )
-    dice = traits.Float( desc='Fuzzy Dice Index (fDI), all the classes' )
-    diff_file = File(exists=True, desc='resulting difference-map of all classes, using the chosen weighting' )
-    class_fji = traits.List( traits.Float(), desc='Array containing the fJIs of each computed class' )
-    class_fdi = traits.List( traits.Float(), desc='Array containing the fDIs of each computed class' )
+    jaccard = traits.Float(desc='Fuzzy Jaccard Index (fJI), all the classes')
+    dice = traits.Float(desc='Fuzzy Dice Index (fDI), all the classes')
+    diff_file = File(exists=True, desc='resulting difference-map of all classes, using the chosen weighting')
+    class_fji = traits.List(traits.Float(), desc='Array containing the fJIs of each computed class')
+    class_fdi = traits.List(traits.Float(), desc='Array containing the fDIs of each computed class')
 
 
 class FuzzyOverlap(BaseInterface):
@@ -405,61 +406,60 @@ class FuzzyOverlap(BaseInterface):
     >>> res = overlap.run() # doctest: +SKIP
     """
 
-    input_spec =  FuzzyOverlapInputSpec
+    input_spec = FuzzyOverlapInputSpec
     output_spec = FuzzyOverlapOutputSpec
 
     def _run_interface(self, runtime):
         ncomp = len(self.inputs.in_ref)
-        assert( ncomp == len(self.inputs.in_tst) )
-        weights = np.ones( shape=ncomp )
-
-        img_ref = np.array( [ nb.load( fname ).get_data() for fname in self.inputs.in_ref ] )
-        img_tst = np.array( [ nb.load( fname ).get_data() for fname in self.inputs.in_tst ] )
+        assert(ncomp == len(self.inputs.in_tst))
+        weights = np.ones(shape=ncomp)
 
+        img_ref = np.array([nb.load(fname, mmap=NUMPY_MMAP).get_data() for fname in self.inputs.in_ref])
+        img_tst = np.array([nb.load(fname, mmap=NUMPY_MMAP).get_data() for fname in self.inputs.in_tst])
 
         msk = np.sum(img_ref, axis=0)
-        msk[msk>0] = 1.0
+        msk[msk > 0] = 1.0
         tst_msk = np.sum(img_tst, axis=0)
-        tst_msk[tst_msk>0] = 1.0
+        tst_msk[tst_msk > 0] = 1.0
 
-        #check that volumes are normalized
-        #img_ref[:][msk>0] = img_ref[:][msk>0] / (np.sum( img_ref, axis=0 ))[msk>0]
-        #img_tst[tst_msk>0] = img_tst[tst_msk>0] / np.sum( img_tst, axis=0 )[tst_msk>0]
+        # check that volumes are normalized
+        # img_ref[:][msk>0] = img_ref[:][msk>0] / (np.sum( img_ref, axis=0 ))[msk>0]
+        # img_tst[tst_msk>0] = img_tst[tst_msk>0] / np.sum( img_tst, axis=0 )[tst_msk>0]
 
         self._jaccards = []
         volumes = []
 
-        diff_im = np.zeros( img_ref.shape )
+        diff_im = np.zeros(img_ref.shape)
 
-        for ref_comp, tst_comp, diff_comp in zip( img_ref, img_tst, diff_im ):
-            num = np.minimum( ref_comp, tst_comp )
-            ddr = np.maximum( ref_comp, tst_comp )
-            diff_comp[ddr>0]+= 1.0-(num[ddr>0]/ddr[ddr>0])
-            self._jaccards.append( np.sum( num ) / np.sum( ddr ) )
-            volumes.append( np.sum( ref_comp ) )
+        for ref_comp, tst_comp, diff_comp in zip(img_ref, img_tst, diff_im):
+            num = np.minimum(ref_comp, tst_comp)
+            ddr = np.maximum(ref_comp, tst_comp)
+            diff_comp[ddr > 0] += 1.0 - (num[ddr > 0] / ddr[ddr > 0])
+            self._jaccards.append(np.sum(num) / np.sum(ddr))
+            volumes.append(np.sum(ref_comp))
 
-        self._dices = 2.0*np.array(self._jaccards) / (np.array(self._jaccards) +1.0 )
+        self._dices = 2.0 * (np.array(self._jaccards) /
+                             (np.array(self._jaccards) + 1.0))
 
         if self.inputs.weighting != "none":
             weights = 1.0 / np.array(volumes)
             if self.inputs.weighting == "squared_vol":
-                weights = weights**2
+                weights = weights ** 2
 
-        weights = weights / np.sum( weights )
+        weights = weights / np.sum(weights)
 
-        setattr( self, '_jaccard',  np.sum( weights * self._jaccards ) )
-        setattr( self, '_dice', np.sum( weights * self._dices ) )
+        setattr(self, '_jaccard', np.sum(weights * self._jaccards))
+        setattr(self, '_dice', np.sum(weights * self._dices))
 
+        diff = np.zeros(diff_im[0].shape)
 
-        diff = np.zeros( diff_im[0].shape )
-
-        for w,ch in zip(weights,diff_im):
-            ch[msk==0] = 0
-            diff+= w* ch
-
-        nb.save(nb.Nifti1Image(diff, nb.load( self.inputs.in_ref[0]).get_affine(),
-                nb.load(self.inputs.in_ref[0]).get_header()), self.inputs.out_file)
+        for w, ch in zip(weights, diff_im):
+            ch[msk == 0] = 0
+            diff += w * ch
 
+        nb.save(nb.Nifti1Image(diff, nb.load(self.inputs.in_ref[0]).affine,
+                               nb.load(self.inputs.in_ref[0]).header),
+                self.inputs.out_file)
 
         return runtime
 
@@ -467,18 +467,18 @@ class FuzzyOverlap(BaseInterface):
         outputs = self._outputs().get()
         for method in ("dice", "jaccard"):
             outputs[method] = getattr(self, '_' + method)
-        #outputs['volume_difference'] = self._volume
+        # outputs['volume_difference'] = self._volume
         outputs['diff_file'] = os.path.abspath(self.inputs.out_file)
-        outputs['class_fji'] =  np.array(self._jaccards).astype(float).tolist();
-        outputs['class_fdi']=  self._dices.astype(float).tolist();
+        outputs['class_fji'] = np.array(self._jaccards).astype(float).tolist()
+        outputs['class_fdi'] = self._dices.astype(float).tolist()
         return outputs
 
 
 class ErrorMapInputSpec(BaseInterfaceInputSpec):
     in_ref = File(exists=True, mandatory=True,
-                   desc="Reference image. Requires the same dimensions as in_tst.")
+                  desc="Reference image. Requires the same dimensions as in_tst.")
     in_tst = File(exists=True, mandatory=True,
-                   desc="Test image. Requires the same dimensions as in_ref.")
+                  desc="Test image. Requires the same dimensions as in_ref.")
     mask = File(exists=True, desc="calculate overlap only within this mask.")
     metric = traits.Enum("sqeuclidean", "euclidean",
                          desc='error map metric (as implemented in scipy cdist)',
@@ -522,7 +522,7 @@ class ErrorMap(BaseInterface):
             mapshape = ref_data.shape[:-1]
 
         if isdefined(self.inputs.mask):
-            msk = nb.load( self.inputs.mask ).get_data()
+            msk = nb.load(self.inputs.mask).get_data()
             if (mapshape != msk.shape):
                 raise RuntimeError("Mask should match volume shape, \
                                    mask is %s and volumes are %s" %
@@ -532,10 +532,10 @@ class ErrorMap(BaseInterface):
 
         # Flatten both volumes and make the pixel differennce
         mskvector = msk.reshape(-1)
-        msk_idxs = np.where(mskvector==1)
-        refvector = ref_data.reshape(-1,comps)[msk_idxs].astype(np.float32)
-        tstvector = tst_data.reshape(-1,comps)[msk_idxs].astype(np.float32)
-        diffvector = (refvector-tstvector)
+        msk_idxs = np.where(mskvector == 1)
+        refvector = ref_data.reshape(-1, comps)[msk_idxs].astype(np.float32)
+        tstvector = tst_data.reshape(-1, comps)[msk_idxs].astype(np.float32)
+        diffvector = (refvector - tstvector)
 
         # Scale the difference
         if self.inputs.metric == 'sqeuclidean':
@@ -547,29 +547,29 @@ class ErrorMap(BaseInterface):
         elif self.inputs.metric == 'euclidean':
             errvector = np.linalg.norm(diffvector, axis=1)
 
-        errvectorexp = np.zeros_like(mskvector, dtype=np.float32) # The default type is uint8
+        errvectorexp = np.zeros_like(mskvector, dtype=np.float32)  # The default type is uint8
         errvectorexp[msk_idxs] = errvector
 
         # Get averaged error
-        self._distance = np.average(errvector) # Only average the masked voxels
+        self._distance = np.average(errvector)  # Only average the masked voxels
 
         errmap = errvectorexp.reshape(mapshape)
 
-        hdr = nii_ref.get_header().copy()
+        hdr = nii_ref.header.copy()
         hdr.set_data_dtype(np.float32)
         hdr['data_type'] = 16
         hdr.set_data_shape(mapshape)
 
         if not isdefined(self.inputs.out_map):
-            fname,ext = op.splitext(op.basename(self.inputs.in_tst))
-            if ext=='.gz':
-                fname,ext2 = op.splitext(fname)
+            fname, ext = op.splitext(op.basename(self.inputs.in_tst))
+            if ext == '.gz':
+                fname, ext2 = op.splitext(fname)
                 ext = ext2 + ext
             self._out_file = op.abspath(fname + "_errmap" + ext)
         else:
             self._out_file = self.inputs.out_map
 
-        nb.Nifti1Image(errmap.astype(np.float32), nii_ref.get_affine(),
+        nb.Nifti1Image(errmap.astype(np.float32), nii_ref.affine,
                        hdr).to_filename(self._out_file)
 
         return runtime
@@ -587,8 +587,8 @@ class SimilarityInputSpec(BaseInterfaceInputSpec):
     mask1 = File(exists=True, desc="3D volume")
     mask2 = File(exists=True, desc="3D volume")
     metric = traits.Either(traits.Enum('cc', 'cr', 'crl1', 'mi', 'nmi', 'slr'),
-                          traits.Callable(),
-                         desc="""str or callable
+                           traits.Callable(),
+                           desc="""str or callable
 Cost-function for assessing image similarity. If a string,
 one of 'cc': correlation coefficient, 'cr': correlation
 ratio, 'crl1': L1-norm based correlation ratio, 'mi': mutual
@@ -599,7 +599,7 @@ histogram as an input and return a float.""", usedefault=True)
 
 
 class SimilarityOutputSpec(TraitedSpec):
-    similarity = traits.List( traits.Float(desc="Similarity between volume 1 and 2, frame by frame"))
+    similarity = traits.List(traits.Float(desc="Similarity between volume 1 and 2, frame by frame"))
 
 
 class Similarity(BaseInterface):
@@ -630,10 +630,9 @@ class Similarity(BaseInterface):
     def __init__(self, **inputs):
         try:
             package_check('nipy')
-        except Exception, e:
+        except Exception as e:
             self._have_nipy = False
-        super(Similarity,self).__init__(**inputs)
-
+        super(Similarity, self).__init__(**inputs)
 
     def _run_interface(self, runtime):
         if not self._have_nipy:
@@ -647,15 +646,15 @@ class Similarity(BaseInterface):
 
         dims = vol1_nii.get_data().ndim
 
-        if dims==3 or dims==2:
-            vols1 = [ vol1_nii ]
-            vols2 = [ vol2_nii ]
-        if dims==4:
-            vols1 = nb.four_to_three( vol1_nii )
-            vols2 = nb.four_to_three( vol2_nii )
+        if dims == 3 or dims == 2:
+            vols1 = [vol1_nii]
+            vols2 = [vol2_nii]
+        if dims == 4:
+            vols1 = nb.four_to_three(vol1_nii)
+            vols2 = nb.four_to_three(vol2_nii)
 
-        if dims<2 or dims>4:
-            raise RuntimeError( 'Image dimensions not supported (detected %dD file)' % dims )
+        if dims < 2 or dims > 4:
+            raise RuntimeError('Image dimensions not supported (detected %dD file)' % dims)
 
         if isdefined(self.inputs.mask1):
             mask1 = nb.load(self.inputs.mask1).get_data() == 1
@@ -669,13 +668,13 @@ class Similarity(BaseInterface):
 
         self._similarity = []
 
-        for ts1,ts2 in zip( vols1, vols2 ):
-            histreg = HistogramRegistration(from_img = ts1,
-                                            to_img = ts2,
+        for ts1, ts2 in zip(vols1, vols2):
+            histreg = HistogramRegistration(from_img=ts1,
+                                            to_img=ts2,
                                             similarity=self.inputs.metric,
-                                            from_mask = mask1,
-                                            to_mask = mask2)
-            self._similarity.append( histreg.eval(Affine()) )
+                                            from_mask=mask1,
+                                            to_mask=mask2)
+            self._similarity.append(histreg.eval(Affine()))
 
         return runtime
 
