@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """
@@ -17,23 +18,24 @@ These functions include:
    >>> datadir = os.path.realpath(os.path.join(filepath, '../testing/data'))
    >>> os.chdir(datadir)
 """
+from __future__ import (print_function, division,
+                        unicode_literals, absolute_import)
+from builtins import open, range, str, bytes
 
 import os
 from copy import deepcopy
-from warnings import warn
 
 from nibabel import load, funcs, Nifti1Image
 import numpy as np
 from scipy import signal
 import scipy.io as sio
-from nipype.external import six
 
+from ..utils import NUMPY_MMAP
 from ..interfaces.base import (BaseInterface, traits, InputMultiPath,
-                                    OutputMultiPath, TraitedSpec, File,
-                                    BaseInterfaceInputSpec, isdefined)
+                               OutputMultiPath, TraitedSpec, File,
+                               BaseInterfaceInputSpec, isdefined)
 from ..utils.filemanip import filename_to_list, save_json, split_filename
-from ..utils.misc import find_indices
-
+from ..utils.misc import find_indices, normalize_mc_params
 from .. import logging, config
 iflogger = logging.getLogger('interface')
 
@@ -45,16 +47,13 @@ def _get_affine_matrix(params, source):
     source : the package that generated the parameters
              supports SPM, AFNI, FSFAST, FSL, NIPY
     """
-    if source == 'FSL':
-        params = params[[3, 4, 5, 0, 1, 2]]
-    elif source in ('AFNI', 'FSFAST'):
-        params = params[np.asarray([4, 5, 3, 1, 2, 0]) + (len(params) > 6)]
-        params[3:] = params[3:] * np.pi / 180.
     if source == 'NIPY':
         # nipy does not store typical euler angles, use nipy to convert
         from nipy.algorithms.registration import to_matrix44
         return to_matrix44(params)
-    #process for FSL, SPM, AFNI and FSFAST
+
+    params = normalize_mc_params(params, source)
+    # process for FSL, SPM, AFNI and FSFAST
     rotfunc = lambda x: np.array([[np.cos(x), np.sin(x)],
                                   [-np.sin(x), np.cos(x)]])
     q = np.array([0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0])
@@ -101,6 +100,29 @@ def _calc_norm(mc, use_differences, source, brain_pts=None):
 
     """
 
+    affines = [_get_affine_matrix(mc[i, :], source)
+               for i in range(mc.shape[0])]
+    return _calc_norm_affine(affines, use_differences, brain_pts)
+
+
+def _calc_norm_affine(affines, use_differences, brain_pts=None):
+    """Calculates the maximum overall displacement of the midpoints
+    of the faces of a cube due to translation and rotation.
+
+    Parameters
+    ----------
+    affines : list of [4 x 4] affine matrices
+    use_differences : boolean
+    brain_pts : [4 x n_points] of coordinates
+
+    Returns
+    -------
+
+    norm : at each time point
+    displacement : euclidean distance (mm) of displacement at each coordinate
+
+    """
+
     if brain_pts is None:
         respos = np.diag([70, 70, 75])
         resneg = np.diag([-70, -110, -45])
@@ -109,90 +131,91 @@ def _calc_norm(mc, use_differences, source, brain_pts=None):
     else:
         all_pts = brain_pts
     n_pts = all_pts.size - all_pts.shape[1]
-    newpos = np.zeros((mc.shape[0], n_pts))
+    newpos = np.zeros((len(affines), n_pts))
     if brain_pts is not None:
-        displacement = np.zeros((mc.shape[0], n_pts / 3))
-    for i in range(mc.shape[0]):
-        affine = _get_affine_matrix(mc[i, :], source)
-        newpos[i, :] = np.dot(affine,
-                              all_pts)[0:3, :].ravel()
+        displacement = np.zeros((len(affines), int(n_pts / 3)))
+    for i, affine in enumerate(affines):
+        newpos[i, :] = np.dot(affine, all_pts)[0:3, :].ravel()
         if brain_pts is not None:
-            displacement[i, :] = \
-                  np.sqrt(np.sum(np.power(np.reshape(newpos[i, :],
-                                                     (3, all_pts.shape[1])) -
-                                          all_pts[0:3, :],
-                                          2),
-                                 axis=0))
+            displacement[i, :] = np.sqrt(np.sum(
+                np.power(np.reshape(newpos[i, :],
+                                    (3, all_pts.shape[1])) - all_pts[0:3, :],
+                         2),
+                axis=0))
     # np.savez('displacement.npz', newpos=newpos, pts=all_pts)
-    normdata = np.zeros(mc.shape[0])
+    normdata = np.zeros(len(affines))
     if use_differences:
         newpos = np.concatenate((np.zeros((1, n_pts)),
                                  np.diff(newpos, n=1, axis=0)), axis=0)
         for i in range(newpos.shape[0]):
             normdata[i] = \
-             np.max(np.sqrt(np.sum(np.reshape(np.power(np.abs(newpos[i, :]), 2),
-                                              (3, all_pts.shape[1])), axis=0)))
+                np.max(np.sqrt(np.sum(
+                    np.reshape(np.power(np.abs(newpos[i, :]), 2),
+                               (3, all_pts.shape[1])),
+                    axis=0)))
     else:
         newpos = np.abs(signal.detrend(newpos, axis=0, type='constant'))
         normdata = np.sqrt(np.mean(np.power(newpos, 2), axis=1))
     return normdata, displacement
 
 
-def _nanmean(a, axis=None):
-    """Return the mean excluding items that are nan
-
-    >>> a = [1, 2, np.nan]
-    >>> _nanmean(a)
-    1.5
-
-    """
-    if axis:
-        return np.nansum(a, axis) / np.sum(1 - np.isnan(a), axis)
-    else:
-        return np.nansum(a) / np.sum(1 - np.isnan(a))
-
-
 class ArtifactDetectInputSpec(BaseInterfaceInputSpec):
     realigned_files = InputMultiPath(File(exists=True),
-                                desc="Names of realigned functional data files",
+                                     desc=("Names of realigned functional data "
+                                           "files"),
                                      mandatory=True)
-    realignment_parameters = InputMultiPath(File(exists=True), mandatory=True,
-                            desc=("Names of realignment parameters"
-                                  "corresponding to the functional data files"))
+    realignment_parameters = InputMultiPath(File(exists=True),
+                                            mandatory=True,
+                                            desc=("Names of realignment "
+                                                  "parameters corresponding to "
+                                                  "the functional data files"))
     parameter_source = traits.Enum("SPM", "FSL", "AFNI", "NiPy", "FSFAST",
                                    desc="Source of movement parameters",
                                    mandatory=True)
-    use_differences = traits.ListBool([True, False], minlen=2, maxlen=2,
+    use_differences = traits.ListBool([True, False],
+                                      minlen=2,
+                                      maxlen=2,
                                       usedefault=True,
-            desc=("Use differences between successive motion (first element)"
-                  "and intensity paramter (second element) estimates in order"
-                  "to determine outliers.  (default is [True, False])"))
-    use_norm = traits.Bool(True, requires=['norm_threshold'],
+                                      desc=("Use differences between successive"
+                                            " motion (first element) and "
+                                            "intensity parameter (second "
+                                            "element) estimates in order to "
+                                            "determine outliers.  "
+                                            "(default is [True, False])"))
+    use_norm = traits.Bool(True,
+                           usedefault=True,
+                           requires=['norm_threshold'],
                            desc=("Uses a composite of the motion parameters in "
-                                 "order to determine outliers."),
-                           usedefault=True)
-    norm_threshold = traits.Float(desc=("Threshold to use to detect motion-rela"
+                                 "order to determine outliers."))
+    norm_threshold = traits.Float(xor=['rotation_threshold',
+                                       'translation_threshold'],
+                                  mandatory=True,
+                                  desc=("Threshold to use to detect motion-rela"
                                         "ted outliers when composite motion is "
-                                        "being used"), mandatory=True,
-                                  xor=['rotation_threshold',
-                                       'translation_threshold'])
-    rotation_threshold = traits.Float(mandatory=True, xor=['norm_threshold'],
-            desc=("Threshold (in radians) to use to detect rotation-related "
-                  "outliers"))
-    translation_threshold = traits.Float(mandatory=True, xor=['norm_threshold'],
-            desc=("Threshold (in mm) to use to detect translation-related "
-                 "outliers"))
+                                        "being used"))
+    rotation_threshold = traits.Float(mandatory=True,
+                                      xor=['norm_threshold'],
+                                      desc=("Threshold (in radians) to use to "
+                                            "detect rotation-related outliers"))
+    translation_threshold = traits.Float(mandatory=True,
+                                         xor=['norm_threshold'],
+                                         desc=("Threshold (in mm) to use to "
+                                               "detect translation-related "
+                                               "outliers"))
     zintensity_threshold = traits.Float(mandatory=True,
-            desc=("Intensity Z-threshold use to detection images that deviate "
-                  "from the mean"))
+                                        desc=("Intensity Z-threshold use to "
+                                              "detection images that deviate "
+                                              "from the mean"))
     mask_type = traits.Enum('spm_global', 'file', 'thresh',
-            desc=("Type of mask that should be used to mask the functional "
-                  "data. *spm_global* uses an spm_global like calculation to "
-                  "determine the brain mask. *file* specifies a brain mask "
-                  "file (should be an image file consisting of 0s and 1s). "
-                  "*thresh* specifies a threshold to use. By default all voxels"
-                  "are used, unless one of these mask types are defined."),
-                            mandatory=True)
+                            mandatory=True,
+                            desc=("Type of mask that should be used to mask the"
+                                  " functional data. *spm_global* uses an "
+                                  "spm_global like calculation to determine the"
+                                  " brain mask. *file* specifies a brain mask "
+                                  "file (should be an image file consisting of "
+                                  "0s and 1s). *thresh* specifies a threshold "
+                                  "to use. By default all voxels are used,"
+                                  "unless one of these mask types are defined"))
     mask_file = File(exists=True,
                      desc="Mask file to be used if mask_type is 'file'.")
     mask_threshold = traits.Float(desc=("Mask threshold to be used if mask_type"
@@ -206,10 +229,10 @@ class ArtifactDetectInputSpec(BaseInterfaceInputSpec):
                             desc="file type of the outlier plot",
                             usedefault=True)
     bound_by_brainmask = traits.Bool(False, desc=("use the brain mask to "
-                                                 "determine bounding box"
-                                                 "for composite norm (works"
-                                                 "for SPM and Nipy - currently"
-                                                 "inaccurate for FSL, AFNI"),
+                                                  "determine bounding box"
+                                                  "for composite norm (works"
+                                                  "for SPM and Nipy - currently"
+                                                  "inaccurate for FSL, AFNI"),
                                      usedefault=True)
     global_threshold = traits.Float(8.0, desc=("use this threshold when mask "
                                                "type equal's spm_global"),
@@ -218,28 +241,36 @@ class ArtifactDetectInputSpec(BaseInterfaceInputSpec):
 
 class ArtifactDetectOutputSpec(TraitedSpec):
     outlier_files = OutputMultiPath(File(exists=True),
-            desc=("One file for each functional run containing a list of "
-                  "0-based indices corresponding to outlier volumes"))
+                                    desc=("One file for each functional run "
+                                          "containing a list of 0-based indices"
+                                          " corresponding to outlier volumes"))
     intensity_files = OutputMultiPath(File(exists=True),
-            desc=("One file for each functional run containing the global "
-                  "intensity values determined from the brainmask"))
+                                      desc=("One file for each functional run "
+                                            "containing the global intensity "
+                                            "values determined from the "
+                                            "brainmask"))
     norm_files = OutputMultiPath(File,
-            desc=("One file for each functional run containing the composite "
-                  "norm"))
+                                 desc=("One file for each functional run "
+                                       "containing the composite norm"))
     statistic_files = OutputMultiPath(File(exists=True),
-            desc=("One file for each functional run containing information "
-                  "about the different types of artifacts and if design info is"
-                  " provided then details of stimulus correlated motion and a "
-                  "listing or artifacts by event type."))
+                                      desc=("One file for each functional run "
+                                            "containing information about the "
+                                            "different types of artifacts and "
+                                            "if design info is provided then "
+                                            "details of stimulus correlated "
+                                            "motion and a listing or artifacts "
+                                            "by event type."))
     plot_files = OutputMultiPath(File,
-            desc=("One image file for each functional run containing the "
-                  "detected outliers"))
+                                 desc=("One image file for each functional run "
+                                       "containing the detected outliers"))
     mask_files = OutputMultiPath(File,
-            desc=("One image file for each functional run containing the mask"
-                  "used for global signal calculation"))
+                                 desc=("One image file for each functional run "
+                                       "containing the mask used for global "
+                                       "signal calculation"))
     displacement_files = OutputMultiPath(File,
-            desc=("One image file for each functional run containing the voxel"
-                  "displacement timeseries"))
+                                         desc=("One image file for each "
+                                               "functional run containing the "
+                                               "voxel displacement timeseries"))
 
 
 class ArtifactDetect(BaseInterface):
@@ -247,7 +278,9 @@ class ArtifactDetect(BaseInterface):
 
     Uses intensity and motion parameters to infer outliers. If `use_norm` is
     True, it computes the movement of the center of each face a cuboid centered
-    around the head and returns the maximal movement across the centers.
+    around the head and returns the maximal movement across the centers. If you
+    wish to use individual thresholds instead, import `Undefined` from
+    `nipype.interfaces.base` and set `....inputs.use_norm = Undefined`
 
 
     Examples
@@ -260,7 +293,7 @@ class ArtifactDetect(BaseInterface):
     >>> ad.inputs.norm_threshold = 1
     >>> ad.inputs.use_differences = [True, False]
     >>> ad.inputs.zintensity_threshold = 3
-    >>> ad.run() # doctest: +SKIP
+    >>> ad.run()  # doctest: +SKIP
     """
 
     input_spec = ArtifactDetectInputSpec
@@ -280,7 +313,7 @@ class ArtifactDetect(BaseInterface):
         output_dir: string
             output directory in which the files will be generated
         """
-        if isinstance(motionfile, six.string_types):
+        if isinstance(motionfile, (str, bytes)):
             infile = motionfile
         elif isinstance(motionfile, list):
             infile = motionfile[0]
@@ -318,7 +351,7 @@ class ArtifactDetect(BaseInterface):
         for i, f in enumerate(filename_to_list(self.inputs.realigned_files)):
             (outlierfile, intensityfile, statsfile, normfile, plotfile,
              displacementfile, maskfile) = \
-                                      self._get_output_filenames(f, os.getcwd())
+                self._get_output_filenames(f, os.getcwd())
             outputs['outlier_files'].insert(i, outlierfile)
             outputs['intensity_files'].insert(i, intensityfile)
             outputs['statistic_files'].insert(i, statsfile)
@@ -332,6 +365,8 @@ class ArtifactDetect(BaseInterface):
         return outputs
 
     def _plot_outliers_with_wave(self, wave, outliers, name):
+        import matplotlib
+        matplotlib.use(config.get("execution", "matplotlib_backend"))
         import matplotlib.pyplot as plt
         plt.plot(wave)
         plt.ylim([wave.min(), wave.max()])
@@ -351,20 +386,20 @@ class ArtifactDetect(BaseInterface):
             cwd = os.getcwd()
 
         # read in functional image
-        if isinstance(imgfile, six.string_types):
-            nim = load(imgfile)
+        if isinstance(imgfile, (str, bytes)):
+            nim = load(imgfile, mmap=NUMPY_MMAP)
         elif isinstance(imgfile, list):
             if len(imgfile) == 1:
-                nim = load(imgfile[0])
+                nim = load(imgfile[0], mmap=NUMPY_MMAP)
             else:
-                images = [load(f) for f in imgfile]
+                images = [load(f, mmap=NUMPY_MMAP) for f in imgfile]
                 nim = funcs.concat_images(images)
 
         # compute global intensity signal
-        (x, y, z, timepoints) = nim.get_shape()
+        (x, y, z, timepoints) = nim.shape
 
         data = nim.get_data()
-        affine = nim.get_affine()
+        affine = nim.affine
         g = np.zeros((timepoints, 1))
         masktype = self.inputs.mask_type
         if masktype == 'spm_global':  # spm_global like calculation
@@ -376,11 +411,11 @@ class ArtifactDetect(BaseInterface):
                     vol = data[:, :, :, t0]
                     # Use an SPM like approach
                     mask_tmp = vol > \
-                               (_nanmean(vol) / self.inputs.global_threshold)
+                        (np.nanmean(vol) / self.inputs.global_threshold)
                     mask = mask * mask_tmp
                 for t0 in range(timepoints):
                     vol = data[:, :, :, t0]
-                    g[t0] = _nanmean(vol[mask])
+                    g[t0] = np.nanmean(vol[mask])
                 if len(find_indices(mask)) < (np.prod((x, y, z)) / 10):
                     intersect_mask = False
                     g = np.zeros((timepoints, 1))
@@ -390,25 +425,25 @@ class ArtifactDetect(BaseInterface):
                 for t0 in range(timepoints):
                     vol = data[:, :, :, t0]
                     mask_tmp = vol > \
-                                 (_nanmean(vol) / self.inputs.global_threshold)
+                        (np.nanmean(vol) / self.inputs.global_threshold)
                     mask[:, :, :, t0] = mask_tmp
-                    g[t0] = np.nansum(vol * mask_tmp)/np.nansum(mask_tmp)
+                    g[t0] = np.nansum(vol * mask_tmp) / np.nansum(mask_tmp)
         elif masktype == 'file':  # uses a mask image to determine intensity
-            maskimg = load(self.inputs.mask_file)
+            maskimg = load(self.inputs.mask_file, mmap=NUMPY_MMAP)
             mask = maskimg.get_data()
-            affine = maskimg.get_affine()
+            affine = maskimg.affine
             mask = mask > 0.5
             for t0 in range(timepoints):
                 vol = data[:, :, :, t0]
-                g[t0] = _nanmean(vol[mask])
+                g[t0] = np.nanmean(vol[mask])
         elif masktype == 'thresh':  # uses a fixed signal threshold
             for t0 in range(timepoints):
                 vol = data[:, :, :, t0]
                 mask = vol > self.inputs.mask_threshold
-                g[t0] = _nanmean(vol[mask])
+                g[t0] = np.nanmean(vol[mask])
         else:
             mask = np.ones((x, y, z))
-            g = _nanmean(data[mask > 0, :], 1)
+            g = np.nanmean(data[mask > 0, :], 1)
 
         # compute normalized intensity values
         gz = signal.detrend(g, axis=0)  # detrend the signal
@@ -460,18 +495,18 @@ class ArtifactDetect(BaseInterface):
             traval = mc[:, 0:3]  # translation parameters (mm)
             rotval = mc[:, 3:6]  # rotation parameters (rad)
             tidx = find_indices(np.sum(abs(traval) >
-                                       self.inputs.translation_threshold, 1)
-                                > 0)
+                                       self.inputs.translation_threshold, 1) >
+                                0)
             ridx = find_indices(np.sum(abs(rotval) >
                                        self.inputs.rotation_threshold, 1) > 0)
 
         outliers = np.unique(np.union1d(iidx, np.union1d(tidx, ridx)))
 
         # write output to outputfile
-        np.savetxt(artifactfile, outliers, fmt='%d', delimiter=' ')
-        np.savetxt(intensityfile, g, fmt='%.2f', delimiter=' ')
+        np.savetxt(artifactfile, outliers, fmt=b'%d', delimiter=' ')
+        np.savetxt(intensityfile, g, fmt=b'%.2f', delimiter=' ')
         if self.inputs.use_norm:
-            np.savetxt(normfile, normval, fmt='%.4f', delimiter=' ')
+            np.savetxt(normfile, normval, fmt=b'%.4f', delimiter=' ')
 
         if isdefined(self.inputs.save_plot) and self.inputs.save_plot:
             import matplotlib
@@ -508,26 +543,28 @@ class ArtifactDetect(BaseInterface):
                                                          motion_outliers)),
                   'motion_outliers': len(np.setdiff1d(motion_outliers, iidx)),
                   },
-         {'motion': [{'using differences': self.inputs.use_differences[0]},
-                      {'mean': np.mean(mc_in, axis=0).tolist(),
-                       'min': np.min(mc_in, axis=0).tolist(),
-                       'max': np.max(mc_in, axis=0).tolist(),
-                       'std': np.std(mc_in, axis=0).tolist()},
-                      ]},
-         {'intensity': [{'using differences': self.inputs.use_differences[1]},
-                         {'mean': np.mean(gz, axis=0).tolist(),
-                          'min': np.min(gz, axis=0).tolist(),
-                          'max': np.max(gz, axis=0).tolist(),
-                          'std': np.std(gz, axis=0).tolist()},
-                         ]},
+                 {'motion': [
+                    {'using differences': self.inputs.use_differences[0]},
+                    {'mean': np.mean(mc_in, axis=0).tolist(),
+                     'min': np.min(mc_in, axis=0).tolist(),
+                     'max': np.max(mc_in, axis=0).tolist(),
+                     'std': np.std(mc_in, axis=0).tolist()},
+                             ]},
+                 {'intensity': [
+                    {'using differences': self.inputs.use_differences[1]},
+                    {'mean': np.mean(gz, axis=0).tolist(),
+                     'min': np.min(gz, axis=0).tolist(),
+                     'max': np.max(gz, axis=0).tolist(),
+                     'std': np.std(gz, axis=0).tolist()},
+                                ]},
                  ]
         if self.inputs.use_norm:
             stats.insert(3, {'motion_norm':
-                                 {'mean': np.mean(normval, axis=0).tolist(),
-                                  'min': np.min(normval, axis=0).tolist(),
-                                  'max': np.max(normval, axis=0).tolist(),
-                                  'std': np.std(normval, axis=0).tolist(),
-                                  }})
+                             {'mean': np.mean(normval, axis=0).tolist(),
+                              'min': np.min(normval, axis=0).tolist(),
+                              'max': np.max(normval, axis=0).tolist(),
+                              'std': np.std(normval, axis=0).tolist(),
+                              }})
         save_json(statsfile, stats)
 
     def _run_interface(self, runtime):
@@ -542,20 +579,27 @@ class ArtifactDetect(BaseInterface):
 
 
 class StimCorrInputSpec(BaseInterfaceInputSpec):
-    realignment_parameters = InputMultiPath(File(exists=True), mandatory=True,
-        desc=('Names of realignment parameters corresponding to the functional '
-              'data files'))
-    intensity_values = InputMultiPath(File(exists=True), mandatory=True,
-              desc='Name of file containing intensity values')
-    spm_mat_file = File(exists=True, mandatory=True,
-                        desc='SPM mat file (use pre-estimate SPM.mat file)')
+    realignment_parameters = InputMultiPath(File(exists=True),
+                                            mandatory=True,
+                                            desc=("Names of realignment "
+                                                  "parameters corresponding to "
+                                                  "the functional data files"))
+    intensity_values = InputMultiPath(File(exists=True),
+                                      mandatory=True,
+                                      desc=("Name of file containing intensity "
+                                           "values"))
+    spm_mat_file = File(exists=True,
+                        mandatory=True,
+                        desc="SPM mat file (use pre-estimate SPM.mat file)")
     concatenated_design = traits.Bool(mandatory=True,
-              desc='state if the design matrix contains concatenated sessions')
+                                      desc=("state if the design matrix "
+                                            "contains concatenated sessions"))
 
 
 class StimCorrOutputSpec(TraitedSpec):
     stimcorr_files = OutputMultiPath(File(exists=True),
-                     desc='List of files containing correlation values')
+                                     desc=("List of files containing "
+                                           "correlation values"))
 
 
 class StimulusCorrelation(BaseInterface):
@@ -565,8 +609,9 @@ class StimulusCorrelation(BaseInterface):
     Currently this class supports an SPM generated design matrix and requires
     intensity parameters. This implies that one must run
     :ref:`ArtifactDetect <nipype.algorithms.rapidart.ArtifactDetect>`
-    and :ref:`Level1Design <nipype.interfaces.spm.model.Level1Design>` prior to running this or
-    provide an SPM.mat file and intensity parameters through some other means.
+    and :ref:`Level1Design <nipype.interfaces.spm.model.Level1Design>` prior to
+    running this or provide an SPM.mat file and intensity parameters through
+    some other means.
 
     Examples
     --------
@@ -642,7 +687,8 @@ class StimulusCorrelation(BaseInterface):
         U = spmmat['SPM'][0][0].Sess[0][sessidx].U[0]
         if rows is None:
             rows = spmmat['SPM'][0][0].Sess[0][sessidx].row[0] - 1
-        cols = spmmat['SPM'][0][0].Sess[0][sessidx].col[0][range(len(U))] - 1
+        cols = (
+            spmmat['SPM'][0][0].Sess[0][sessidx].col[0][list(range(len(U)))]-1)
         outmatrix = designmatrix.take(rows.tolist(), axis=0).take(cols.tolist(),
                                                                   axis=1)
         return outmatrix
