@@ -1,38 +1,33 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from shutil import rmtree
-from tempfile import mkdtemp
-from nipype.testing import (assert_equal, example_data)
+from nipype.testing import example_data
+from nipype.utils import NUMPY_MMAP
 
 
-def test_split_and_merge():
+def test_split_and_merge(tmpdir):
     import numpy as np
     import nibabel as nb
     import os.path as op
     import os
-    cwd = os.getcwd()
 
     from nipype.algorithms.misc import split_rois, merge_rois
-    tmpdir = mkdtemp()
 
     in_mask = example_data('tpms_msk.nii.gz')
-    dwfile = op.join(tmpdir, 'dwi.nii.gz')
-    mskdata = nb.load(in_mask).get_data()
-    aff = nb.load(in_mask).get_affine()
+    dwfile = tmpdir.join('dwi.nii.gz').strpath
+    mskdata = nb.load(in_mask, mmap=NUMPY_MMAP).get_data()
+    aff = nb.load(in_mask, mmap=NUMPY_MMAP).affine
 
     dwshape = (mskdata.shape[0], mskdata.shape[1], mskdata.shape[2], 6)
     dwdata = np.random.normal(size=dwshape)
-    os.chdir(tmpdir)
+    tmpdir.chdir()
     nb.Nifti1Image(dwdata.astype(np.float32),
                    aff, None).to_filename(dwfile)
 
     resdw, resmsk, resid = split_rois(dwfile, in_mask, roishape=(20, 20, 2))
     merged = merge_rois(resdw, resid, in_mask)
-    dwmerged = nb.load(merged).get_data()
+    dwmerged = nb.load(merged, mmap=NUMPY_MMAP).get_data()
 
     dwmasked = dwdata * mskdata[:, :, :, np.newaxis]
-    os.chdir(cwd)
-    rmtree(tmpdir)
 
-    yield assert_equal, np.allclose(dwmasked, dwmerged), True
+    assert np.allclose(dwmasked, dwmerged)
