@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """
 Using nipype with persistence and lazy recomputation but without explicit
 name-steps pipeline: getting back scope in command-line based programming.
@@ -8,6 +9,8 @@ name-steps pipeline: getting back scope in command-line based programming.
    >>> datadir = os.path.realpath(os.path.join(filepath, '../testing/data'))
    >>> os.chdir(datadir)
 """
+from __future__ import print_function, division, unicode_literals, absolute_import
+from builtins import object, open
 
 import os
 import hashlib
@@ -16,13 +19,14 @@ import time
 import shutil
 import glob
 
-from nipype.interfaces.base import BaseInterface
-from nipype.pipeline.engine import Node
-from nipype.pipeline.utils import modify_paths
+from ..interfaces.base import BaseInterface
+from ..pipeline.engine import Node
+from ..pipeline.engine.utils import modify_paths
 
 ################################################################################
 # PipeFunc object: callable interface to nipype.interface objects
 
+
 class PipeFunc(object):
     """ Callable interface to nipype.interface objects
 
@@ -47,8 +51,8 @@ class PipeFunc(object):
                 An optional callable called each time after the function
                 is called.
         """
-        if not (isinstance(interface, type)
-                                and issubclass(interface, BaseInterface)):
+        if not (isinstance(interface, type) and
+                issubclass(interface, BaseInterface)):
             raise ValueError('the interface argument should be a nipype '
                              'interface class, but %s (type %s) was passed.' %
                              (interface, type(interface)))
@@ -58,7 +62,7 @@ class PipeFunc(object):
             raise ValueError('base_dir should be an existing directory')
         self.base_dir = base_dir
         doc = '%s\n%s' % (self.interface.__doc__,
-                            self.interface.help(returnhelp=True))
+                          self.interface.help(returnhelp=True))
         self.__doc__ = doc
         self.callback = callback
 
@@ -66,7 +70,7 @@ class PipeFunc(object):
         kwargs = modify_paths(kwargs, relative=False)
         interface = self.interface()
         # Set the inputs early to get some argument checking
-        interface.inputs.set(**kwargs)
+        interface.inputs.trait_set(**kwargs)
         # Make a name for our node
         inputs = interface.inputs.get_hashval()
         hasher = hashlib.new('md5')
@@ -89,23 +93,25 @@ class PipeFunc(object):
         return out
 
     def __repr__(self):
-        return '%s(%s.%s, base_dir=%s)' % (self.__class__.__name__,
-                           self.interface.__module__,
-                           self.interface.__name__,
-                           self.base_dir)
+        return '{}({}.{}}, base_dir={})'.format(
+            self.__class__.__name__, self.interface.__module__, self.interface.__name__,
+            self.base_dir)
 
 ################################################################################
 # Memory manager: provide some tracking about what is computed when, to
 # be able to flush the disk
 
+
 def read_log(filename, run_dict=None):
     if run_dict is None:
         run_dict = dict()
-    for line in open(filename, 'r'):
-        dir_name, job_name = line[:-1].split('/')
-        jobs = run_dict.get(dir_name, set())
-        jobs.add(job_name)
-        run_dict[dir_name] = jobs
+
+    with open(filename, 'r') as logfile:
+        for line in logfile:
+            dir_name, job_name = line[:-1].split('/')
+            jobs = run_dict.get(dir_name, set())
+            jobs.add(job_name)
+            run_dict[dir_name] = jobs
     return run_dict
 
 
@@ -130,7 +136,7 @@ def rm_all_but(base_dir, dirs_to_keep, warn=False):
         dir_name = os.path.join(base_dir, dir_name)
         if os.path.exists(dir_name):
             if warn:
-                print 'removing directory: %s' % dir_name
+                print('removing directory: %s' % dir_name)
             shutil.rmtree(dir_name)
 
 
@@ -171,7 +177,7 @@ class Memory(object):
         elif not os.path.isdir(base_dir):
             raise ValueError('base_dir should be a directory')
         self.base_dir = base_dir
-        open(os.path.join(base_dir, 'log.current'), 'w')
+        open(os.path.join(base_dir, 'log.current'), 'a').close()
 
     def cache(self, interface):
         """ Returns a callable that caches the output of an interface
@@ -221,8 +227,9 @@ class Memory(object):
         # Every counter is a file opened in append mode and closed
         # immediately to avoid race conditions in parallel computing:
         # file appends are atomic
-        open(os.path.join(base_dir, 'log.current'),
-            'a').write('%s/%s\n' % (dir_name, job_name))
+        with open(os.path.join(base_dir, 'log.current'), 'a') as currentlog:
+            currentlog.write('%s/%s\n' % (dir_name, job_name))
+
         t = time.localtime()
         year_dir = os.path.join(base_dir, 'log.%i' % t.tm_year)
         try:
@@ -234,8 +241,9 @@ class Memory(object):
             os.mkdir(month_dir)
         except OSError:
             "Dir exists"
-        open(os.path.join(month_dir, '%02i.log' % t.tm_mday),
-            'a').write('%s/%s\n' % (dir_name, job_name))
+
+        with open(os.path.join(month_dir, '%02i.log' % t.tm_mday), 'a') as rotatefile:
+            rotatefile.write('%s/%s\n' % (dir_name, job_name))
 
     def clear_previous_runs(self, warn=True):
         """ Remove all the cache that where not used in the latest run of
@@ -271,7 +279,7 @@ class Memory(object):
         year = year if year is not None else t.tm_year
         base_dir = self.base_dir
         cut_off_file = '%s/log.%i/%02i/%02i.log' % (base_dir,
-                    year, month, day)
+                                                    year, month, day)
         logs_to_flush = list()
         recent_runs = dict()
         for log_name in glob.glob('%s/log.*/*/*.log' % base_dir):
@@ -288,11 +296,9 @@ class Memory(object):
             input.
         """
         rm_all_but(self.base_dir, set(runs.keys()), warn=warn)
-        for dir_name, job_names in runs.iteritems():
+        for dir_name, job_names in list(runs.items()):
             rm_all_but(os.path.join(self.base_dir, dir_name),
                        job_names, warn=warn)
 
     def __repr__(self):
-        return '%s(base_dir=%s)' % (self.__class__.__name__,
-                           self.base_dir)
-
+        return '{}(base_dir={})'.format(self.__class__.__name__, self.base_dir)
