@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """
     Change directory to provide relative paths for doctests
     >>> import os
@@ -6,22 +7,24 @@
     >>> os.chdir(datadir)
 
 """
+from __future__ import print_function, division, unicode_literals, absolute_import
+
 import os
 
-from nipype.interfaces.base import (CommandLineInputSpec, CommandLine, traits,
-                                    TraitedSpec, File, StdOutCommandLine,
-                                    StdOutCommandLineInputSpec, isdefined)
-from nipype.utils.filemanip import split_filename
+from ...utils.filemanip import split_filename
+from ..base import (traits, TraitedSpec, File, StdOutCommandLine,
+                    StdOutCommandLineInputSpec)
+
 
 class SFPICOCalibDataInputSpec(StdOutCommandLineInputSpec):
     snr = traits.Float(argstr='-snr %f', units='NA',
                        desc=('Specifies  the  signal-to-noise ratio of the '
-                            'non-diffusion-weighted measurements to use in simulations.'))
+                             'non-diffusion-weighted measurements to use in simulations.'))
     scheme_file = File(exists=True, argstr='-schemefile %s', mandatory=True,
                        desc='Specifies the scheme file for the diffusion MRI data')
     info_file = File(desc='The name to be given to the information output filename.',
                      argstr='-infooutputfile %s', mandatory=True, genfile=True,
-                     hash_files=False) # Genfile and hash_files?
+                     hash_files=False)  # Genfile and hash_files?
     trace = traits.Float(argstr='-trace %f', units='NA',
                          desc='Trace of the diffusion tensor(s) used in the test function.')
     onedtfarange = traits.List(traits.Float, argstr='-onedtfarange %s',
@@ -38,16 +41,16 @@ class SFPICOCalibDataInputSpec(StdOutCommandLineInputSpec):
                                      'to give all the different permutations.'))
     twodtfastep = traits.Float(argstr='-twodtfastep %f', units='NA',
                                desc=('FA step size controlling how many steps there are '
-                                    'between the minimum and maximum FA settings '
-                                    'for the two tensor cases.'))
+                                     'between the minimum and maximum FA settings '
+                                     'for the two tensor cases.'))
     twodtanglerange = traits.List(traits.Float, argstr='-twodtanglerange %s',
                                   minlen=2, maxlen=2, units='NA',
                                   desc=('Minimum and maximum crossing angles '
                                         'between the two fibres.'))
     twodtanglestep = traits.Float(argstr='-twodtanglestep %f', units='NA',
-                               desc=('Angle step size controlling how many steps there are '
-                                     'between the minimum and maximum crossing angles for '
-                                     'the two tensor cases.'))
+                                  desc=('Angle step size controlling how many steps there are '
+                                        'between the minimum and maximum crossing angles for '
+                                        'the two tensor cases.'))
     twodtmixmax = traits.Float(argstr='-twodtmixmax %f', units='NA',
                                desc=('Mixing parameter controlling the proportion of one fibre population '
                                      'to the other. The minimum mixing parameter is (1 - twodtmixmax).'))
@@ -57,10 +60,12 @@ class SFPICOCalibDataInputSpec(StdOutCommandLineInputSpec):
     seed = traits.Float(argstr='-seed %f', units='NA',
                         desc='Specifies the random seed to use for noise generation in simulation trials.')
 
+
 class SFPICOCalibDataOutputSpec(TraitedSpec):
     PICOCalib = File(exists=True, desc='Calibration dataset')
     calib_info = File(exists=True, desc='Calibration dataset')
 
+
 class SFPICOCalibData(StdOutCommandLine):
     """
     Generates Spherical Function PICo Calibration Data.
@@ -114,8 +119,8 @@ class SFPICOCalibData(StdOutCommandLine):
     data is generated for calculating the LUT.      # doctest: +SKIP
     """
     _cmd = 'sfpicocalibdata'
-    input_spec=SFPICOCalibDataInputSpec
-    output_spec=SFPICOCalibDataOutputSpec
+    input_spec = SFPICOCalibDataInputSpec
+    output_spec = SFPICOCalibDataOutputSpec
 
     def _list_outputs(self):
         outputs = self.output_spec().get()
@@ -124,11 +129,10 @@ class SFPICOCalibData(StdOutCommandLine):
         return outputs
 
     def _gen_outfilename(self):
-        _, name , _ = split_filename(self.inputs.scheme_file)
+        _, name, _ = split_filename(self.inputs.scheme_file)
         return name + '_PICOCalib.Bfloat'
 
 
-
 class SFLUTGenInputSpec(StdOutCommandLineInputSpec):
     in_file = File(exists=True, argstr='-inputfile %s', mandatory=True,
                    desc='Voxel-order data of the spherical functions peaks.')
@@ -167,10 +171,12 @@ class SFLUTGenInputSpec(StdOutCommandLineInputSpec):
                        desc=('The order of the polynomial fitting the surface. Order 1 is linear. '
                              'Order 2 (default) is quadratic.'))
 
+
 class SFLUTGenOutputSpec(TraitedSpec):
     lut_one_fibre = File(exists=True, desc='PICo lut for one-fibre model')
     lut_two_fibres = File(exists=True, desc='PICo lut for two-fibre model')
 
+
 class SFLUTGen(StdOutCommandLine):
     """
     Generates PICo lookup tables (LUT) for multi-fibre methods such as
@@ -220,8 +226,8 @@ class SFLUTGen(StdOutCommandLine):
     >>> lutgen.run()        # doctest: +SKIP
     """
     _cmd = 'sflutgen'
-    input_spec=SFLUTGenInputSpec
-    output_spec=SFLUTGenOutputSpec
+    input_spec = SFLUTGenInputSpec
+    output_spec = SFLUTGenOutputSpec
 
     def _list_outputs(self):
         outputs = self.output_spec().get()
