@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Provides interfaces to various commands provided by diffusion toolkit
@@ -9,21 +10,25 @@
    >>> os.chdir(datadir)
 
 """
-import re
-from nipype.utils.filemanip import fname_presuffix, split_filename, copyfile
+from __future__ import print_function, division, unicode_literals, absolute_import
+from builtins import range, open
+
 import os
+import re
+
+from ...utils.filemanip import fname_presuffix, split_filename, copyfile
+from ..base import (TraitedSpec, File, traits, CommandLine,
+                    CommandLineInputSpec, isdefined)
+
 __docformat__ = 'restructuredtext'
 
-from nipype.interfaces.base import (TraitedSpec, File, traits, CommandLine,
-                                    CommandLineInputSpec, isdefined)
-
 class DTIReconInputSpec(CommandLineInputSpec):
-    DWI = File(desc='Input diffusion volume', argstr='%s',exists=True, mandatory=True,position=1)
-    out_prefix = traits.Str("dti", desc='Output file prefix', argstr='%s', usedefault=True,position=2)
+    DWI = File(desc='Input diffusion volume', argstr='%s', exists=True, mandatory=True, position=1)
+    out_prefix = traits.Str("dti", desc='Output file prefix', argstr='%s', usedefault=True, position=2)
     output_type = traits.Enum('nii', 'analyze', 'ni1', 'nii.gz', argstr='-ot %s', desc='output file type', usedefault=True)
-    bvecs = File(exists=True, desc = 'b vectors file',
-                argstr='-gm %s', mandatory=True)
-    bvals = File(exists=True,desc = 'b values file', mandatory=True)
+    bvecs = File(exists=True, desc='b vectors file',
+                 argstr='-gm %s', mandatory=True)
+    bvals = File(exists=True, desc='b values file', mandatory=True)
     n_averages = traits.Int(desc='Number of averages', argstr='-nex %s')
     image_orientation_vectors = traits.List(traits.Float(), minlen=6, maxlen=6, desc="""specify image orientation vectors. if just one argument given,
         will treat it as filename and read the orientation vectors from
@@ -54,27 +59,28 @@ class DTIReconOutputSpec(TraitedSpec):
     V2 = File(exists=True)
     V3 = File(exists=True)
 
+
 class DTIRecon(CommandLine):
     """Use dti_recon to generate tensors and other maps
     """
 
-    input_spec=DTIReconInputSpec
-    output_spec=DTIReconOutputSpec
+    input_spec = DTIReconInputSpec
+    output_spec = DTIReconOutputSpec
 
     _cmd = 'dti_recon'
 
     def _create_gradient_matrix(self, bvecs_file, bvals_file):
         _gradient_matrix_file = 'gradient_matrix.txt'
-        bvals = [val for val in  re.split('\s+', open(bvals_file).readline().strip())]
-        bvecs_f = open(bvecs_file)
-        bvecs_x = [val for val in  re.split('\s+', bvecs_f.readline().strip())]
-        bvecs_y = [val for val in  re.split('\s+', bvecs_f.readline().strip())]
-        bvecs_z = [val for val in  re.split('\s+', bvecs_f.readline().strip())]
-        bvecs_f.close()
-        gradient_matrix_f = open(_gradient_matrix_file, 'w')
-        for i in range(len(bvals)):
-            gradient_matrix_f.write("%s, %s, %s, %s\n"%(bvecs_x[i], bvecs_y[i], bvecs_z[i], bvals[i]))
-        gradient_matrix_f.close()
+        with open(bvals_file) as fbvals:
+            bvals = [val for val in re.split('\s+', fbvals.readline().strip())]
+        with open(bvecs_file) as fbvecs:
+            bvecs_y = [val for val in re.split('\s+', fbvecs.readline().strip())]
+            bvecs_z = [val for val in re.split('\s+', fbvecs.readline().strip())]
+            bvecs_x = [val for val in re.split('\s+', fbvecs.readline().strip())]
+
+        with open(_gradient_matrix_file, 'w') as gradient_matrix_f:
+            for i in range(len(bvals)):
+                gradient_matrix_f.write("%s, %s, %s, %s\n" % (bvecs_x[i], bvecs_y[i], bvecs_z[i], bvals[i]))
         return _gradient_matrix_file
 
     def _format_arg(self, name, spec, value):
@@ -88,21 +94,22 @@ class DTIRecon(CommandLine):
         output_type = self.inputs.output_type
 
         outputs = self.output_spec().get()
-        outputs['ADC'] = os.path.abspath(fname_presuffix("",  prefix=out_prefix, suffix='_adc.'+ output_type))
-        outputs['B0'] = os.path.abspath(fname_presuffix("",  prefix=out_prefix, suffix='_b0.'+ output_type))
-        outputs['L1'] = os.path.abspath(fname_presuffix("",  prefix=out_prefix, suffix='_e1.'+ output_type))
-        outputs['L2'] = os.path.abspath(fname_presuffix("",  prefix=out_prefix, suffix='_e2.'+ output_type))
-        outputs['L3'] = os.path.abspath(fname_presuffix("",  prefix=out_prefix, suffix='_e3.'+ output_type))
-        outputs['exp'] = os.path.abspath(fname_presuffix("",  prefix=out_prefix, suffix='_exp.'+ output_type))
-        outputs['FA'] = os.path.abspath(fname_presuffix("",  prefix=out_prefix, suffix='_fa.'+ output_type))
-        outputs['FA_color'] = os.path.abspath(fname_presuffix("",  prefix=out_prefix, suffix='_fa_color.'+ output_type))
-        outputs['tensor'] = os.path.abspath(fname_presuffix("",  prefix=out_prefix, suffix='_tensor.'+ output_type))
-        outputs['V1'] = os.path.abspath(fname_presuffix("",  prefix=out_prefix, suffix='_v1.'+ output_type))
-        outputs['V2'] = os.path.abspath(fname_presuffix("",  prefix=out_prefix, suffix='_v2.'+ output_type))
-        outputs['V3'] = os.path.abspath(fname_presuffix("",  prefix=out_prefix, suffix='_v3.'+ output_type))
+        outputs['ADC'] = os.path.abspath(fname_presuffix("", prefix=out_prefix, suffix='_adc.' + output_type))
+        outputs['B0'] = os.path.abspath(fname_presuffix("", prefix=out_prefix, suffix='_b0.' + output_type))
+        outputs['L1'] = os.path.abspath(fname_presuffix("", prefix=out_prefix, suffix='_e1.' + output_type))
+        outputs['L2'] = os.path.abspath(fname_presuffix("", prefix=out_prefix, suffix='_e2.' + output_type))
+        outputs['L3'] = os.path.abspath(fname_presuffix("", prefix=out_prefix, suffix='_e3.' + output_type))
+        outputs['exp'] = os.path.abspath(fname_presuffix("", prefix=out_prefix, suffix='_exp.' + output_type))
+        outputs['FA'] = os.path.abspath(fname_presuffix("", prefix=out_prefix, suffix='_fa.' + output_type))
+        outputs['FA_color'] = os.path.abspath(fname_presuffix("", prefix=out_prefix, suffix='_fa_color.' + output_type))
+        outputs['tensor'] = os.path.abspath(fname_presuffix("", prefix=out_prefix, suffix='_tensor.' + output_type))
+        outputs['V1'] = os.path.abspath(fname_presuffix("", prefix=out_prefix, suffix='_v1.' + output_type))
+        outputs['V2'] = os.path.abspath(fname_presuffix("", prefix=out_prefix, suffix='_v2.' + output_type))
+        outputs['V3'] = os.path.abspath(fname_presuffix("", prefix=out_prefix, suffix='_v3.' + output_type))
 
         return outputs
 
+
 class DTITrackerInputSpec(CommandLineInputSpec):
     tensor_file = File(exists=True, desc="reconstructed tensor file")
     input_type = traits.Enum('nii', 'analyze', 'ni1', 'nii.gz', desc="""input and output file type. accepted values are:
@@ -110,7 +117,7 @@ class DTITrackerInputSpec(CommandLineInputSpec):
         ni1     -> nifti format saved in seperate .hdr and .img file
         nii     -> nifti format with one .nii file
         nii.gz  -> nifti format with compression
-        default type is 'nii'""", argstr = "-it %s")
+        default type is 'nii'""", argstr="-it %s")
     tracking_method = traits.Enum('fact', 'rk2', 'tl', 'sl', desc="""fact -> use FACT method for tracking. this is the default method.
         rk2  -> use 2nd order runge-kutta method for tracking.
         tl   -> use tensorline method for tracking.
@@ -120,15 +127,15 @@ class DTITrackerInputSpec(CommandLineInputSpec):
         and 0.1 for other methods""", argstr="-l %f")
     angle_threshold = traits.Float(desc="set angle threshold. default value is 35 degree", argstr="-at %f")
     angle_threshold_weight = traits.Float(desc="set angle threshold weighting factor. weighting will be be applied \
-        on top of the angle_threshold", argstr = "-atw %f")
-    random_seed = traits.Int(desc = "use random location in a voxel instead of the center of the voxel \
+        on top of the angle_threshold", argstr="-atw %f")
+    random_seed = traits.Int(desc="use random location in a voxel instead of the center of the voxel \
           to seed. can also define number of seed per voxel. default is 1", argstr="-rseed")
-    invert_x = traits.Bool(desc="invert x component of the vector", argstr = "-ix")
-    invert_y = traits.Bool(desc="invert y component of the vector", argstr = "-iy")
-    invert_z = traits.Bool(desc="invert z component of the vector", argstr = "-iz")
-    swap_xy = traits.Bool(desc="swap x & y vectors while tracking", argstr = "-sxy")
-    swap_yz = traits.Bool(desc="swap y & z vectors while tracking", argstr = "-syz")
-    swap_zx = traits.Bool(desc="swap x & z vectors while tracking", argstr = "-szx")
+    invert_x = traits.Bool(desc="invert x component of the vector", argstr="-ix")
+    invert_y = traits.Bool(desc="invert y component of the vector", argstr="-iy")
+    invert_z = traits.Bool(desc="invert z component of the vector", argstr="-iz")
+    swap_xy = traits.Bool(desc="swap x & y vectors while tracking", argstr="-sxy")
+    swap_yz = traits.Bool(desc="swap y & z vectors while tracking", argstr="-syz")
+    swap_zx = traits.Bool(desc="swap x & z vectors while tracking", argstr="-szx")
     mask1_file = File(desc="first mask image", mandatory=True, argstr="-m %s", position=2)
     mask1_threshold = traits.Float(desc="threshold value for the first mask image, if not given, the program will \
         try automatically find the threshold", position=3)
@@ -138,15 +145,17 @@ class DTITrackerInputSpec(CommandLineInputSpec):
     input_data_prefix = traits.Str("dti", desc="for internal naming use only", position=0, argstr="%s", usedefault=True)
     output_file = File("tracks.trk", "file containing tracks", argstr="%s", position=1, usedefault=True)
     output_mask = File(desc="output a binary mask file in analyze format", argstr="-om %s")
-    primary_vector = traits.Enum('v2', 'v3', desc = "which vector to use for fibre tracking: v2 or v3. If not set use v1", argstr="-%s")
+    primary_vector = traits.Enum('v2', 'v3', desc="which vector to use for fibre tracking: v2 or v3. If not set use v1", argstr="-%s")
+
 
 class DTITrackerOutputSpec(TraitedSpec):
     track_file = File(exists=True)
     mask_file = File(exists=True)
 
+
 class DTITracker(CommandLine):
-    input_spec=DTITrackerInputSpec
-    output_spec=DTITrackerOutputSpec
+    input_spec = DTITrackerInputSpec
+    output_spec = DTITrackerOutputSpec
 
     _cmd = 'dti_tracker'
 
@@ -162,4 +171,4 @@ class DTITracker(CommandLine):
         if isdefined(self.inputs.output_mask) and self.inputs.output_mask:
             outputs['mask_file'] = os.path.abspath(self.inputs.output_mask)
 
-        return outputs
\ No newline at end of file
+        return outputs
