@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # coding: utf-8
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
@@ -9,11 +10,11 @@ the elastix registration software.
 
 
 """
+from __future__ import print_function, division, unicode_literals, absolute_import
 
-from ..base import (CommandLine, CommandLineInputSpec, isdefined,
-                    TraitedSpec, File, Directory, traits, InputMultiPath)
 from ... import logging
-logger = logging.getLogger('interface')
+from ..base import CommandLineInputSpec, Directory, traits
+iflogger = logging.getLogger('interface')
 
 
 class ElastixBaseInputSpec(CommandLineInputSpec):
