@@ -11,16 +11,12 @@
     >>> os.chdir(datadir)
 
 """
-import os
+from __future__ import print_function, division, unicode_literals, absolute_import
+
 import os.path as op
 
-from base import MRTrix3BaseInputSpec, MRTrix3Base
-from nipype.interfaces.base import (
-    CommandLineInputSpec, CommandLine, traits, TraitedSpec, File,
-    InputMultiPath)
-
-from nipype.utils.filemanip import split_filename
-from nipype.interfaces.traits_extension import isdefined
+from ..base import traits, TraitedSpec, File
+from .base import MRTrix3BaseInputSpec, MRTrix3Base
 
 
 class FitTensorInputSpec(MRTrix3BaseInputSpec):
