@@ -1,33 +1,40 @@
+# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Parallel workflow execution via IPython controller
 """
+from __future__ import print_function, division, unicode_literals, absolute_import
 
-from cPickle import dumps
+from future import standard_library
+standard_library.install_aliases()
+from future.utils import raise_from
+
+from pickle import dumps
 
 import sys
+from .base import (DistributedPluginBase, logger, report_crash)
 
 IPython_not_loaded = False
 try:
     from IPython import __version__ as IPyversion
-    from IPython.parallel.error import TimeoutError
+    from ipyparallel.error import TimeoutError
 except:
     IPython_not_loaded = True
 
-from .base import (DistributedPluginBase, logger, report_crash)
+
 
 def execute_task(pckld_task, node_config, updatehash):
     from socket import gethostname
     from traceback import format_exc
     from nipype import config, logging
-    traceback=None
-    result=None
+    traceback = None
+    result = None
     import os
     cwd = os.getcwd()
     try:
         config.update_config(node_config)
         logging.update_logging(config)
-        from cPickle import loads
+        from pickle import loads
         task = loads(pckld_task)
         result = task.run(updatehash=updatehash)
     except:
@@ -36,14 +43,20 @@ def execute_task(pckld_task, node_config, updatehash):
     os.chdir(cwd)
     return result, traceback, gethostname()
 
+
 class IPythonPlugin(DistributedPluginBase):
     """Execute workflow with ipython
     """
 
     def __init__(self, plugin_args=None):
         if IPython_not_loaded:
-            raise ImportError('IPython parallel could not be imported')
+            raise ImportError('Please install ipyparallel to use this plugin.')
         super(IPythonPlugin, self).__init__(plugin_args=plugin_args)
+        valid_args = ('url_file', 'profile', 'cluster_id', 'context', 'debug',
+                      'timeout', 'config', 'username', 'sshserver', 'sshkey',
+                      'password', 'paramiko')
+        self.client_args = {arg: plugin_args[arg]
+                            for arg in valid_args if arg in plugin_args}
         self.iparallel = None
         self.taskclient = None
         self.taskmap = {}
@@ -51,26 +64,27 @@ class IPythonPlugin(DistributedPluginBase):
 
     def run(self, graph, config, updatehash=False):
         """Executes a pre-defined pipeline is distributed approaches
-        based on IPython's parallel processing interface
+        based on IPython's ipyparallel processing interface
         """
         # retrieve clients again
         try:
-            name = 'IPython.parallel'
+            name = 'ipyparallel'
             __import__(name)
             self.iparallel = sys.modules[name]
-        except ImportError:
-            raise ImportError("Ipython kernel not found. Parallel execution " \
-                              "will be unavailable")
+        except ImportError as e:
+            raise_from(ImportError("ipyparallel not found. Parallel execution "
+                                   "will be unavailable"), e)
         try:
-            self.taskclient = self.iparallel.Client()
-        except Exception, e:
+            self.taskclient = self.iparallel.Client(**self.client_args)
+        except Exception as e:
             if isinstance(e, TimeoutError):
-                raise Exception("No IPython clients found.")
+                raise_from(Exception("No IPython clients found."), e)
             if isinstance(e, IOError):
-                raise Exception("ipcluster/ipcontroller has not been started")
+                raise_from(Exception("ipcluster/ipcontroller has not been started"), e)
             if isinstance(e, ValueError):
-                raise Exception("Ipython kernel not installed")
-            raise e
+                raise_from(Exception("Ipython kernel not installed"), e)
+            else:
+                raise e
         return super(IPythonPlugin, self).run(graph, config, updatehash=updatehash)
 
     def _get_result(self, taskid):
@@ -107,6 +121,6 @@ class IPythonPlugin(DistributedPluginBase):
 
     def _clear_task(self, taskid):
         if IPyversion >= '0.11':
-            logger.debug("Clearing id: %d"%taskid)
+            logger.debug("Clearing id: %d" % taskid)
             self.taskclient.purge_results(self.taskmap[taskid])
             del self.taskmap[taskid]
