@@ -1,5 +1,9 @@
+# -*- coding: utf-8 -*-
 """Parallel workflow execution via SGE
 """
+from __future__ import print_function, division, unicode_literals, absolute_import
+
+from builtins import object
 
 import os
 import pwd
@@ -11,9 +15,10 @@ import xml.dom.minidom
 
 import random
 
-from .base import (SGELikeBatchManagerBase, logger, iflogger, logging)
-from nipype.interfaces.base import CommandLine
-
+from ... import logging
+from ...interfaces.base import CommandLine
+from .base import SGELikeBatchManagerBase, logger
+iflogger = logging.getLogger('interface')
 DEBUGGING_PREFIX = str(int(random.uniform(100, 999)))
 
 
@@ -24,7 +29,7 @@ def sge_debug_print(message):
     # print DEBUGGING_PREFIX + " " + "=!" * 3 + "  " + message
 
 
-class QJobInfo:
+class QJobInfo(object):
 
     """Information about a single job created by OGE/SGE or similar
     Each job is responsible for knowing it's own refresh state
@@ -43,22 +48,20 @@ class QJobInfo:
         self._job_info_creation_time = time.time(
         )  # When this job was created (for comparing against initalization)
         self._job_queue_name = job_queue_name  # Where the job is running
-        self._job_slots = job_slots  # How many slots are being used
+        self._job_slots = int(job_slots)  # How many slots are being used
         self._qsub_command_line = qsub_command_line
 
     def __repr__(self):
-        return str(self._job_num).ljust(8) \
-            + str(self._job_queue_state).ljust(12) \
-            + str(self._job_slots).ljust(3) \
-            + time.strftime("%Y-%m-%dT%H:%M:%S", time.gmtime(self._job_time)).ljust(20) \
-            + str(self._job_queue_name).ljust(8) \
-            + str(self._qsub_command_line)
+        return '{:<8d}{:12}{:<3d}{:20}{:8}{}'.format(
+            self._job_num, self._job_queue_state, self._job_slots,
+            time.strftime("%Y-%m-%dT%H:%M:%S", time.gmtime(self._job_time)),
+            self._job_queue_name, self._qsub_command_line)
 
     def is_initializing(self):
         return self._job_queue_state == "initializing"
 
     def is_zombie(self):
-        return self._job_queue_state == "zombie"
+        return self._job_queue_state == "zombie" or self._job_queue_state == "finished"
 
     def is_running(self):
         return self._job_queue_state == "running"
@@ -89,13 +92,13 @@ class QJobInfo:
         self._job_queue_state = job_queue_state
         self._job_time = job_time
         self._job_queue_name = job_queue_name
-        self._job_slots = job_slots
+        self._job_slots = int(job_slots)
 
     def set_state(self, new_state):
         self._job_queue_state = new_state
 
 
-class QstatSubstitute:
+class QstatSubstitute(object):
 
     """A wrapper for Qstat to avoid overloading the
     SGE/OGS server with rapid continuous qstat requests"""
@@ -174,10 +177,10 @@ class QstatSubstitute:
             except:
                 job_queue_name = "unknown"
             try:
-                job_slots = current_job_element.getElementsByTagName(
-                    'slots')[0].childNodes[0].data
+                job_slots = int(current_job_element.getElementsByTagName(
+                    'slots')[0].childNodes[0].data)
             except:
-                job_slots = "unknown"
+                job_slots = -1
             job_queue_state = current_job_element.getAttribute('state')
             job_num = int(current_job_element.getElementsByTagName(
                 'JB_job_number')[0].childNodes[0].data)
@@ -209,7 +212,7 @@ class QstatSubstitute:
         # were started and finished, and pushed out of the window of review
         # before their state being recorded.  The qacct command is slower, but
         # much more robust for ensuring that a job has completed.
-        for dictionary_job in self._task_dictionary.keys():
+        for dictionary_job in list(self._task_dictionary.keys()):
             if dictionary_job not in current_jobs_parsed:
                 is_completed = self._qacct_verified_complete(dictionary_job)
                 if is_completed:
@@ -271,7 +274,7 @@ class QstatSubstitute:
 
     def print_dictionary(self):
         """For debugging"""
-        for vv in self._task_dictionary.values():
+        for vv in list(self._task_dictionary.values()):
             sge_debug_print(str(vv))
 
     def is_job_pending(self, task_id):
@@ -361,7 +364,8 @@ class SGEPlugin(SGELikeBatchManagerBase):
         return self._refQstatSubstitute.is_job_pending(int(taskid))
 
     def _submit_batchtask(self, scriptfile, node):
-        cmd = CommandLine('qsub', environ=os.environ.data,
+        cmd = CommandLine('qsub', environ=dict(os.environ),
+                          resource_monitor=False,
                           terminal_output='allatonce')
         path = os.path.dirname(scriptfile)
         qsubargs = ''
@@ -378,11 +382,11 @@ class SGEPlugin(SGELikeBatchManagerBase):
         if '-e' not in qsubargs:
             qsubargs = '%s -e %s' % (qsubargs, path)
         if node._hierarchy:
-            jobname = '.'.join((os.environ.data['LOGNAME'],
+            jobname = '.'.join((dict(os.environ)['LOGNAME'],
                                 node._hierarchy,
                                 node._id))
         else:
-            jobname = '.'.join((os.environ.data['LOGNAME'],
+            jobname = '.'.join((dict(os.environ)['LOGNAME'],
                                 node._id))
         jobnameitems = jobname.split('.')
         jobnameitems.reverse()
@@ -398,7 +402,7 @@ class SGEPlugin(SGELikeBatchManagerBase):
         while True:
             try:
                 result = cmd.run()
-            except Exception, e:
+            except Exception as e:
                 if tries < self._max_tries:
                     tries += 1
                     time.sleep(
