@@ -5,17 +5,18 @@ Created on Aug 2, 2013
 
 Parallel workflow execution with SLURM
 '''
+from __future__ import print_function, division, unicode_literals, absolute_import
+from builtins import open
 
 import os
 import re
-import subprocess
 from time import sleep
 
-from .base import (SGELikeBatchManagerBase, logger, iflogger, logging)
-
-from nipype.interfaces.base import CommandLine
-
+from ... import logging
+from ...interfaces.base import CommandLine
+from .base import SGELikeBatchManagerBase, logger
 
+iflogger = logging.getLogger('interface')
 
 
 class SLURMPlugin(SGELikeBatchManagerBase):
@@ -32,25 +33,28 @@ class SLURMPlugin(SGELikeBatchManagerBase):
 
     '''
 
-
     def __init__(self, **kwargs):
 
-        template="#!/bin/bash"
+        template = "#!/bin/bash"
 
         self._retry_timeout = 2
         self._max_tries = 2
         self._template = template
         self._sbatch_args = None
+        self._jobid_re = "Submitted batch job ([0-9]*)"
 
         if 'plugin_args' in kwargs and kwargs['plugin_args']:
             if 'retry_timeout' in kwargs['plugin_args']:
                 self._retry_timeout = kwargs['plugin_args']['retry_timeout']
-            if  'max_tries' in kwargs['plugin_args']:
+            if 'max_tries' in kwargs['plugin_args']:
                 self._max_tries = kwargs['plugin_args']['max_tries']
+            if 'jobid_re' in kwargs['plugin_args']:
+                self._jobid_re = kwargs['plugin_args']['jobid_re']
             if 'template' in kwargs['plugin_args']:
                 self._template = kwargs['plugin_args']['template']
                 if os.path.isfile(self._template):
-                    self._template = open(self._template).read()
+                    with open(self._template) as f:
+                        self._template = f.read()
             if 'sbatch_args' in kwargs['plugin_args']:
                 self._sbatch_args = kwargs['plugin_args']['sbatch_args']
         self._pending = {}
@@ -58,19 +62,20 @@ class SLURMPlugin(SGELikeBatchManagerBase):
 
     def _is_pending(self, taskid):
         #  subprocess.Popen requires taskid to be a string
-        proc = subprocess.Popen(["squeue", '-j', '%s' % taskid],
-                                stdout=subprocess.PIPE,
-                                stderr=subprocess.PIPE)
-        o, _ = proc.communicate()
-
-        return o.find(str(taskid)) > -1
+        res = CommandLine('squeue',
+                          args=' '.join(['-j', '%s' % taskid]),
+                          resource_monitor=False,
+                          terminal_output='allatonce').run()
+        return res.runtime.stdout.find(str(taskid)) > -1
 
     def _submit_batchtask(self, scriptfile, node):
         """
-        This is more or less the _submit_batchtask from sge.py with flipped variable
-        names, different command line switches, and different output formatting/processing
+        This is more or less the _submit_batchtask from sge.py with flipped
+        variable names, different command line switches, and different output
+        formatting/processing
         """
-        cmd = CommandLine('sbatch', environ=os.environ.data,
+        cmd = CommandLine('sbatch', environ=dict(os.environ),
+                          resource_monitor=False,
                           terminal_output='allatonce')
         path = os.path.dirname(scriptfile)
 
@@ -88,11 +93,11 @@ class SLURMPlugin(SGELikeBatchManagerBase):
         if '-e' not in sbatch_args:
             sbatch_args = '%s -e %s' % (sbatch_args, os.path.join(path, 'slurm-%j.out'))
         if node._hierarchy:
-            jobname = '.'.join((os.environ.data['LOGNAME'],
+            jobname = '.'.join((dict(os.environ)['LOGNAME'],
                                 node._hierarchy,
                                 node._id))
         else:
-            jobname = '.'.join((os.environ.data['LOGNAME'],
+            jobname = '.'.join((dict(os.environ)['LOGNAME'],
                                 node._id))
         jobnameitems = jobname.split('.')
         jobnameitems.reverse()
@@ -106,7 +111,7 @@ class SLURMPlugin(SGELikeBatchManagerBase):
         while True:
             try:
                 result = cmd.run()
-            except Exception, e:
+            except Exception as e:
                 if tries < self._max_tries:
                     tries += 1
                     sleep(self._retry_timeout)  # sleep 2 seconds and try again.
@@ -121,8 +126,9 @@ class SLURMPlugin(SGELikeBatchManagerBase):
         iflogger.setLevel(oldlevel)
         # retrieve taskid
         lines = [line for line in result.runtime.stdout.split('\n') if line]
-        taskid = int(re.match("Submitted batch job ([0-9]*)",
+        taskid = int(re.match(self._jobid_re,
                               lines[-1]).groups()[0])
         self._pending[taskid] = node.output_dir()
         logger.debug('submitted sbatch task: %d for node %s' % (taskid, node._id))
         return taskid
+
