@@ -1,9 +1,13 @@
+# -*- coding: utf-8 -*-
 """Parallel workflow execution via PBS/Torque
 """
+from __future__ import print_function, division, unicode_literals, absolute_import
 
 import os
 import sys
 
+from .base import (GraphPluginBase, logger)
+
 soma_not_loaded = False
 try:
     from soma.workflow.client import (Job, Workflow, WorkflowController,
@@ -12,8 +16,6 @@ except:
     soma_not_loaded = True
 
 
-from .base import (GraphPluginBase, logger)
-
 class SomaFlowPlugin(GraphPluginBase):
     """Execute using Soma workflow
     """
@@ -31,7 +33,7 @@ class SomaFlowPlugin(GraphPluginBase):
             jobs.append(Job(command=[sys.executable,
                                      fname],
                             name=name))
-        for key, values in dependencies.items():
+        for key, values in list(dependencies.items()):
             for val in values:
                 soma_deps.append((jobs[val], jobs[key]))
 
