@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 
@@ -5,7 +6,7 @@ import os
 from nipype.interfaces.fsl.base import no_fsl, no_fsl_course_data
 import nipype.pipeline.engine as pe
 import nipype.interfaces.utility as util
-from nipype.testing import skipif
+import pytest
 import tempfile
 import shutil
 from subprocess import call
@@ -58,7 +59,7 @@ def _tbss_test_helper(estimate_skeleton):
     tbss1_original_datasource.inputs.base_directory = tbss1_orig_dir
     tbss1_original_datasource.inputs.template = 'FA/%s_FA%s.nii.gz'
     tbss1_original_datasource.inputs.template_args = dict(fa_list=[[subjects, '']],
-        mask_list=[[subjects, '_mask']])
+                                                          mask_list=[[subjects, '_mask']])
 
     tbss1_test_fa = pe.MapNode(util.AssertEqual(), name="tbss1_fa_test", iterfield=['volume1', 'volume2'])
     tbss1_test_mask = pe.MapNode(util.AssertEqual(), name="tbss1_mask_test", iterfield=['volume1', 'volume2'])
@@ -78,15 +79,15 @@ def _tbss_test_helper(estimate_skeleton):
     pipeline.connect(tbss2_original_datasource, 'field_list', tbss2_test_field, 'volume2')
 
     tbss3_original_datasource = pe.Node(nio.DataGrabber(outfields=['groupmask',
-                'skeleton_file',
-                'meanfa_file',
-                'mergefa_file'], sort_filelist=False), name='tbss3_original_datasource')
+                                                                   'skeleton_file',
+                                                                   'meanfa_file',
+                                                                   'mergefa_file'], sort_filelist=False), name='tbss3_original_datasource')
     tbss3_original_datasource.inputs.base_directory = tbss3_orig_dir
     tbss3_original_datasource.inputs.template = 'stats/%s.nii.gz'
     tbss3_original_datasource.inputs.template_args = dict(groupmask=[['mean_FA_mask']],
-        skeleton_file=[['mean_FA_skeleton']],
-        meanfa_file=[['mean_FA']],
-        mergefa_file=[['all_FA']])
+                                                          skeleton_file=[['mean_FA_skeleton']],
+                                                          meanfa_file=[['mean_FA']],
+                                                          mergefa_file=[['all_FA']])
 
     tbss3_test_groupmask = pe.Node(util.AssertEqual(), name="tbss3_test_groupmask")
     tbss3_test_skeleton_file = pe.Node(util.AssertEqual(), name="tbss3_test_skeleton_file")
@@ -103,11 +104,11 @@ def _tbss_test_helper(estimate_skeleton):
     pipeline.connect(tbss3_original_datasource, 'mergefa_file', tbss3_test_mergefa_file, 'volume2')
 
     tbss4_original_datasource = pe.Node(nio.DataGrabber(outfields=['all_FA_skeletonised',
-                'mean_FA_skeleton_mask'], sort_filelist=False), name='tbss4_original_datasource')
+                                                                   'mean_FA_skeleton_mask'], sort_filelist=False), name='tbss4_original_datasource')
     tbss4_original_datasource.inputs.base_directory = tbss4_orig_dir
     tbss4_original_datasource.inputs.template = 'stats/%s.nii.gz'
     tbss4_original_datasource.inputs.template_args = dict(all_FA_skeletonised=[['all_FA_skeletonised']],
-        mean_FA_skeleton_mask=[['mean_FA_skeleton_mask']])
+                                                          mean_FA_skeleton_mask=[['mean_FA_skeleton_mask']])
     tbss4_test_all_FA_skeletonised = pe.Node(util.AssertEqual(), name="tbss4_test_all_FA_skeletonised")
     tbss4_test_mean_FA_skeleton_mask = pe.Node(util.AssertEqual(), name="tbss4_test_mean_FA_skeleton_mask")
 
@@ -120,14 +121,18 @@ def _tbss_test_helper(estimate_skeleton):
     os.chdir(old_dir)
     shutil.rmtree(test_dir)
 
+# this test is disabled until we figure out what is wrong with TBSS in 5.0.9
 
-@skipif(no_fsl)
-@skipif(no_fsl_course_data)
-def test_tbss_est_skeleton():
+
+@pytest.mark.skipif(no_fsl(), reason="fsl is not installed")
+@pytest.mark.skipif(no_fsl_course_data(), reason="fsl data not available")
+def test_disabled_tbss_est_skeleton():
     _tbss_test_helper(True)
 
+# this test is disabled until we figure out what is wrong with TBSS in 5.0.9
 
-@skipif(no_fsl)
-@skipif(no_fsl_course_data)
-def test_tbss_est_skeleton_use_precomputed_skeleton():
+
+@pytest.mark.skipif(no_fsl(), reason="fsl is not installed")
+@pytest.mark.skipif(no_fsl_course_data(), reason="fsl data not available")
+def test_disabled_tbss_est_skeleton_use_precomputed_skeleton():
     _tbss_test_helper(False)
